<?php
	// If this file is called directly, abort.
	if ( ! defined( 'WPINC' ) ) {
		die;
	}


	/**
	 * The admin-specific functionality of the plugin.
	 *
	 * @link       https://codeboxr.com
	 * @since      1.0.0
	 *
	 * @package    CBCurrencyConverter
	 * @subpackage CBCurrencyConverter/admin
	 */

	/**
	 * The admin-specific functionality of the plugin.
	 *
	 * Defines the plugin name, version, and two examples hooks for how to
	 * enqueue the admin-specific stylesheet and JavaScript.
	 *
	 * @package    CBCurrencyConverter
	 * @subpackage CBCurrencyConverter/admin
	 * @author     codeboxr <info@codeboxr.com>
	 */
	class CBCurrencyConverter_Admin {

		/**
		 * The ID of this plugin.
		 *
		 * @since    1.0.0
		 * @access   private
		 * @var      string $plugin_name The ID of this plugin.
		 */
		private $plugin_name;


		/**
		 * The version of this plugin.
		 *
		 * @since    1.0.0
		 * @access   private
		 * @var      string $version The current version of this plugin.
		 */
		private $version;

		//for setting
		private $settings_api;

		/**
		 * Initialize the class and set its properties.
		 *
		 * @param string $plugin_name The name of this plugin.
		 * @param string $version     The version of this plugin.
		 *
		 * @since    1.0.0
		 *
		 */
		public function __construct( $plugin_name, $version ) {

			$this->plugin_name = $plugin_name;
			$this->version     = $version;

			$this->settings_api = new CBCurrencyconverterSetting();
		}//end of oonstructor

		/**
		 * Register the stylesheets for the admin area.
		 *
		 * @since    1.0.0
		 */
		public function enqueue_styles( $hook ) {
			$page = isset( $_GET['page'] ) ? esc_attr( wp_unslash( $_GET['page'] ) ) : '';

			wp_register_style( 'select2',plugin_dir_url( __FILE__ ) . '../assets/js/select2/css/select2.min.css', array(), $this->version );
			//wp_register_style( 'selectize',plugin_dir_url( __FILE__ ) . '../assets/js/selectize/css/selectize.default.css', array(), $this->version );

			if ( $page == 'cbcurrencyconverter' ) {

				wp_enqueue_style( 'wp-color-picker' );

				wp_register_style( 'cbcurrencyconverter-public', plugin_dir_url( __FILE__ ) . '../assets/css/cbcurrencyconverter-public.css', array( 'select2' ), $this->version, 'all' );
				wp_register_style( 'cbcurrencyconverter_admin', plugin_dir_url( __FILE__ ) . '../assets/css/cbcurrencyconverter_admin.css', array( 'select2' ), $this->version );



				wp_enqueue_style( 'select2' );
				wp_enqueue_style( 'cbcurrencyconverter-public' );
				wp_enqueue_style( 'cbcurrencyconverter_admin' );
			}

			if ( $hook == 'widgets.php' ) {
				wp_register_style( 'cbcurrencyconverter_widget', plugin_dir_url( __FILE__ ) . '../assets/css/cbcurrencyconverter_widget.css', array(
					'select2',
					//'selectize',
				), $this->version );

				//wp_enqueue_style( 'select2' );
				wp_enqueue_style( 'selectize' );
				wp_enqueue_style( 'cbcurrencyconverter_widget' );
			}
			if ( $page == 'cbcurrencyconverter' || $page == 'cbcurrencyconverter&doc=1') {
				wp_register_style( 'cbcurrencyconverter-branding', plugin_dir_url( __FILE__ ) . '../assets/css/cbcurrencyconverter-branding.css',
					array(),
					$this->version );
				wp_enqueue_style( 'cbcurrencyconverter-branding' );
			}
		}//end enqueue_styles

		/**
		 * Register the JavaScript for the admin area.
		 *
		 * @since    1.0.0
		 */
		public function enqueue_scripts( $hook ) {
			$page = isset( $_GET['page'] ) ? esc_attr( wp_unslash( $_GET['page'] ) ) : '';

			wp_register_script( 'select2', plugin_dir_url( __FILE__ ) . '../assets/js/select2/js/select2.min.js', array( 'jquery' ), $this->version, true );
			//wp_register_script( 'selectize', plugin_dir_url( __FILE__ ) . '../assets/js/selectize/js/standalone/selectize.min.js', array( 'jquery' ), $this->version, true );



			wp_register_script( 'cbcurrencyconverter_admin',
				plugin_dir_url( __FILE__ ) . '../assets/js/cbcurrencyconverter_admin.js',
				array(
					'wp-color-picker',
					'select2',
					'jquery',
				),
				$this->version,
				true );

			wp_register_script( 'cbcurrencyconverter_widget',
				plugin_dir_url( __FILE__ ) . '../assets/js/cbcurrencyconverter_widget.js',
				array(
					'select2',
					//'selectize',
					'jquery',
				),
				$this->version,
				true );

			if ( $page == 'cbcurrencyconverter' ) {
				$ajax_nonce = wp_create_nonce( "cbcurrencyconverter_nonce" );
				wp_register_script( 'cbcurrencyconverter-public',
					plugin_dir_url( __FILE__ ) . '../assets/js/cbcurrencyconverter-public.js',
					array(
						'jquery',
						'select2',
					),
					$this->version,
					true );

				wp_localize_script( 'cbcurrencyconverter-public',
					'cbcurrencyconverter',
					array(
						'ajaxurl'         => admin_url( 'admin-ajax.php' ),
						'nonce'           => $ajax_nonce,
						'empty_selection' => esc_html__( 'Please choose from or to currency properly', 'cbcurrencyconverter' ),
						'same_selection'  => esc_html__( 'From and to currency both are same!', 'cbcurrencyconverter' ),
						'please_select'   => esc_html__( 'Please Select', 'cbcurrencyconverter' ),
					) );

				wp_enqueue_media();
				wp_enqueue_script( 'wp-color-picker' );
				wp_enqueue_script( 'jquery' );

				// Localize the script with new data
				$translation_array = array(
					'chosennoresults' => esc_html__( 'Oops, nothing found!', 'cbcurrencyconverter' ),
					'please_select'   => esc_html__( 'Please Select', 'cbcurrencyconverter' ),
					'upload_btn'      => esc_html__( 'Upload', 'cbcurrencyconverter' ),
					'upload_title'    => esc_html__( 'Select Media', 'cbcurrencyconverter' ),
					'copy_success'    => esc_html__( 'Shortcode copied to clipboard', 'cbcurrencyconverter' ),
					'copy_fail'       => esc_html__( 'Oops, unable to copy', 'cbcurrencyconverter' )
				);

				wp_localize_script( 'cbcurrencyconverter_admin', 'wpcbcurrencyconverter', $translation_array );


				wp_enqueue_script( 'select2' );
				wp_enqueue_script( 'cbcurrencyconverter_admin' );
				wp_enqueue_script( 'cbcurrencyconverter-public' );
			}

			if ( $hook == 'widgets.php' ) {
				// Localize the script with new data
				$translation_array = array(
					'chosennoresults' => esc_html__( 'Oops, nothing found!', 'cbcurrencyconverter' ),
					'please_select'   => esc_html__( 'Please Select', 'cbcurrencyconverter' ),
					'upload_btn'      => esc_html__( 'Upload', 'cbcurrencyconverter' ),
					'upload_title'    => esc_html__( 'Select Media', 'cbcurrencyconverter' )
				);

				wp_localize_script( 'cbcurrencyconverter_widget', 'cbcurrencyconverter_widget', $translation_array );

				wp_enqueue_script( 'select2' );
				//wp_enqueue_script( 'selectize' );
				wp_enqueue_script( 'cbcurrencyconverter_widget' );
			}

			//header scroll
			wp_register_script( 'cbcurrencyconverter-scroll', plugins_url( '../assets/js/cbcurrencyconverter-scroll.js', __FILE__ ), array( 'jquery' ), $this->version );
			if ( $page == 'cbcurrencyconverter' || $page == 'cbcurrencyconverter&doc=1' ) {
				wp_enqueue_script( 'jquery' );
				wp_enqueue_script( 'cbcurrencyconverter-scroll' );
			}
		}//end enqueue_scripts


		/**
		 * Add admin pages
		 */
		public function admin_menus() {

			add_submenu_page( 'options-general.php',
				esc_html__( 'Currency Converter', 'cbcurrencyconverter' ),
				esc_html__( 'Currency Converter', 'cbcurrencyconverter' ),
				'manage_options',
				'cbcurrencyconverter',
				array(
					$this,
					'display_plugin_admin_settings',
				)
			);
		}//end admin_menus


		/**
		 * Render the settings page for this plugin.
		 *
		 * @since    1.0.0
		 */
		public function display_plugin_admin_settings() {
			global $wpdb;
			$plugin_data = get_plugin_data( plugin_dir_path( __DIR__ ) . $this->plugin_name . '.php' );

			$doc = isset($_REQUEST['cbcurrencyconverter-help-support'])? absint($_REQUEST['cbcurrencyconverter-help-support']) : 0;

			if($doc){
				include cbcurrencyconverter_locate_template( 'admin/dashboard.php' );
			}
			else{
				include cbcurrencyconverter_locate_template( 'admin/settings-display.php' );
			}
		}//end display_plugin_admin_settings


		/**
		 * Initalize Setting
		 */
		public function setting_init() {
			//set the settings
			$this->settings_api->set_sections( $this->get_settings_sections() );
			$this->settings_api->set_fields( $this->get_settings_fields() );
			//initialize settings
			$this->settings_api->admin_init();
		}//end setting_init

		/**
		 * Settings Sections
		 */
		public function get_settings_sections() {
			$sections = array(
				array(
					'id'    => 'cbcurrencyconverter_global_settings',
					'title' => esc_html__( 'General', 'cbcurrencyconverter' ),
				),
				array(
					'id'    => 'cbcurrencyconverter_calculator_settings',
					'title' => esc_html__( 'Calculator Default', 'cbcurrencyconverter' ),

				),
				array(
					'id'    => 'cbcurrencyconverter_list_settings',
					'title' => esc_html__( 'List Default', 'cbcurrencyconverter' ),

				),
				array(
					'id'    => 'cbcurrencyconverter_tools',
					'title' => esc_html__( 'Tools', 'cbcurrencyconverter' ),
				),
			);

			return apply_filters( 'cbcurrencyconverter_section', $sections );
		}//end get_settings_sections

		/**
		 * Settings fields
		 */
		public function get_settings_fields() {
			$reset_data_link      = add_query_arg( 'cbcurrencyconverter_fullreset', 1, admin_url( 'options-general.php?page=cbcurrencyconverter' ) );
			$reset_transient_link = add_query_arg( 'cbcurrencyconverter_transientreset', 1, admin_url( 'options-general.php?page=cbcurrencyconverter' ) );

			$table_html = '<p><a  class="button button-primary" id="cbcurrencyconverter_info_trig" href="#">' . esc_html__( 'Show/hide details', 'cbcurrencyconverter' ) . '</a></p>';
			$table_html .= '<div id="cbcurrencyconverter_resetinfo" style="display: none;">';
			$table_html .= '<p><strong>' . esc_html__( 'Following option values created by this plugin(including addon) from wordpress core option table', 'cbcurrencyconverter' ) . '</strong></p>';


			$option_values    = CBCurrencyConverterHelper::getAllOptionNames();
			$transient_caches = CBCurrencyConverterHelper::getAllTransientCacheNames();

			$table_html .= '<table class="widefat" id="cbcurrencyconverter_table_data">
	<thead>
	<tr>
		<th class="row-title">' . esc_attr__( 'Option Name', 'cbcurrencyconverter' ) . '</th>
		<th>' . esc_attr__( 'Option ID', 'cbcurrencyconverter' ) . '</th>
		<th>' . esc_attr__( 'Data', 'cbcurrencyconverter' ) . '</th>
	</tr>
	</thead>
	<tbody>';


			$i = 0;
			foreach ( $option_values as $key => $value ) {
				$alternate_class = ( $i % 2 == 0 ) ? 'alternate' : '';
				$i ++;
				//$table_data_html .= '<p>' .  $value['option_name'] . ' - ' . $value['option_id'] . ' - (<code style="overflow-wrap: break-word; word-break: break-all;">' . $value['option_value'] . '</code>)</p>';

				$table_html .= '<tr class="' . esc_attr( $alternate_class ) . '">
									<td class="row-title"><label for="tablecell">' . esc_attr( $value['option_name'] ) . '</label></td>
									<td>' . esc_attr( $value['option_id'] ) . '</td>
									<td><code style="overflow-wrap: break-word; word-break: break-all;">' . $value['option_value'] . '</code></td>
								</tr>';

			}

			$table_html .= '</tbody>
	<tfoot>
	<tr>
		<th class="row-title">' . esc_attr__( 'Option Name', 'cbcurrencyconverter' ) . '</th>
		<th>' . esc_attr__( 'Option ID', 'cbcurrencyconverter' ) . '</th>
		<th>' . esc_attr__( 'Data', 'cbcurrencyconverter' ) . '</th>
	</tr>
	</tfoot>
</table>';
			$table_html .= '</div>'; //#cbcurrencyconverter_resetinfo


			$table_counter        = 1;
			$transient_table_html = '<p><strong>' . esc_html__( 'Following transient caches are stored by this plugin', 'cbcurrencyconverter' ) . '</strong></p>';
			foreach ( $transient_caches as $value ) {
				$transient_table_html .= '<p>' . str_pad( $table_counter, 2, '0', STR_PAD_LEFT ) . '. ' . $value . ' </p>';
				$table_counter ++;
			}

			$all_currencies = $cal_from_to_list_currency = CBCurrencyConverterHelper::getCurrencyList();


			$setting_cal        = get_option( 'cbcurrencyconverter_calculator_settings' );
			$enabled_currencies = isset( $setting_cal['cbcurrencyconverter_enabledcurrencies_calculator'] ) ? $setting_cal['cbcurrencyconverter_enabledcurrencies_calculator'] : array();

			if ( is_array( $enabled_currencies ) && sizeof( $enabled_currencies ) > 0 ) {

				$all_currencies = CBCurrencyConverterHelper::getCurrencyList();

				foreach ( $cal_from_to_list_currency as $key => $value ) {
					if ( ! in_array( $key, $enabled_currencies ) ) {
						unset( $cal_from_to_list_currency[ $key ] );
					}
				}
			}


			foreach ( $all_currencies as $key => $value ) {
				$all_currencies[ $key ] = $value . ' - ' . $key . '';
			}

			/*foreach ( $cal_from_to_list_currency as $key => $value ) {
				$cal_from_to_list_currencyp[ $key ] = $value . ' - ' . $key;
			}*/

			foreach ( $cal_from_to_list_currency as $key => $value ) {
				$cal_from_to_list_currency[ $key ] = $value . ' - ' . $key;
			}

			//$cbcurrencyconverter_tocurrency_list              = array( 'GBP', 'CAD', 'AUD' );
			//$cbcurrencyconverter_enabledcurrencies_calculator = array( 'USD', 'GBP', 'CAD', 'AUD' );

			$global_settings    = get_option( 'cbcurrencyconverter_global_settings', array() );
			$calculator_setting = get_option( 'cbcurrencyconverter_calculator_settings', array() );
			$list_settings      = get_option( 'cbcurrencyconverter_list_settings', array() );


            $rates_api_titles = CBCurrencyConverterHelper::currency_rates_api_titles();

			$cbcurrencyconverter_global_settings = array(

				'api_source'                        => array(
					'name'    => 'api_source',
					'label'   => esc_html__( 'Api Source', 'cbcurrencyconverter' ),
					'desc'    => esc_html__( 'Different api sources gives different rates based on their historical data', 'cbcurrencyconverter' ),
					'type'    => 'select',
					'default' => 'alphavantage',
					'options' => $rates_api_titles
				),
				'apikey'                            => array(
					'name'    => 'apikey',
					'label'   => esc_html__( 'Alphavantage Api Key', 'cbcurrencyconverter' ),
					'desc'    => __( 'Please collect your key from <a href="https://www.alphavantage.co/support/#api-key" target="_blank">alphavantage.co</a>, it\'s <strong>free</strong>, you can try their pro also', 'cbcurrencyconverter' ),
					'type'    => 'text',
					'default' => '',
				),
                'apikey_open_exg_free'                            => array(
                    'name'    => 'apikey_open_exg_free',
                    'label'   => esc_html__( 'Openexchangerates Api Key(Free)', 'cbcurrencyconverter' ),
                    'desc'    => __( 'Please collect your key from <a href="https://openexchangerates.org/" target="_blank">https://openexchangerates.org</a>, it has both free and pro api', 'cbcurrencyconverter' ),
                    'type'    => 'text',
                    'default' => '',
                ),
                'apikey_clayer_free'                            => array(
                    'name'    => 'apikey_clayer_free',
                    'label'   => esc_html__( 'Currencylayer Api Key(Free)', 'cbcurrencyconverter' ),
                    'desc'    => __( 'Please collect your key from <a href="currencylayer.com" target="_blank">currencylayer.com</a>, it has both free and pro api', 'cbcurrencyconverter' ),
                    'type'    => 'text',
                    'default' => '',
                ),
				'cbcurrencyconverter_defaultlayout' => array(
					'name'    => 'cbcurrencyconverter_defaultlayout',
					'label'   => esc_html__( 'Layout', 'cbcurrencyconverter' ),
					'desc'    => esc_html__( 'Select layout', 'cbcurrencyconverter' ),
					'type'    => 'select',
					'default' => 'cal',
					'options' => array(
						'cal'               => esc_html__( 'Calculator', 'cbcurrencyconverter' ),
						'list'              => esc_html__( 'List', 'cbcurrencyconverter' ),
						'calwithlistbottom' => esc_html__( 'Calculator with List at bottom', 'cbcurrencyconverter' ),
						'calwithlisttop'    => esc_html__( 'Calculator with List at top', 'cbcurrencyconverter' ),
					),
				),
				'cbcurrencyconverter_decimalpoint'  => array(
					'name'    => 'cbcurrencyconverter_decimalpoint',
					'label'   => esc_html__( 'Decimal Point', 'cbcurrencyconverter' ),
					'desc'    => esc_html__( 'decimal point position', 'cbcurrencyconverter' ),
					'type'    => 'number',
					'default' => '2',

				),
				'cbcurrencyconverter_ratecache'     => array(
					'name'    => 'cbcurrencyconverter_ratecache',
					'label'   => esc_html__( 'Use Rate Api Caching', 'cbcurrencyconverter' ),
					'desc'    => esc_html__( 'Rate api caching is recommended', 'cbcurrencyconverter' ),
					'type'    => 'select',
					'default' => 1,
					'options' => array(
						'1' => esc_html__( 'Enable', 'cbcurrencyconverter' ),
						'0' => esc_html__( 'Disable', 'cbcurrencyconverter' ),
					),
				),
				'cbcurrencyconverter_cachetime'     => array(
					'name'    => 'cbcurrencyconverter_cachetime',
					'label'   => esc_html__( 'Rate Api Cache Time', 'cbcurrencyconverter' ),
					'desc'    => sprintf( __( 'Time is in hour, default is 2 hours, rate api cache can be reset from <a target="_blank" href="%s">tools setting</a>', 'cbcurrencyconverter' ), admin_url( 'options-general.php?page=cbcurrencyconverter#cbcurrencyconverter_tools' ) ),
					'type'    => 'number',
					'default' => '2',
					'min'     => 0,
					'max'     => 720,
					'step'    => .01,

				),
				array(
					'name'    => 'shortcode_demo',
					'label'   => esc_html__( 'Shortcode & Demo', 'cbcurrencyconverter' ),
					'desc'    => esc_html__( 'Shortcode and demo based on default setting, please save once to check change.', 'cbcurrencyconverter' ),
					'type'    => 'shortcode',
					'class'   => 'cbcurrencyconverter_demo_copy',
					'default' => CBCurrencyConverterHelper::shortcode_builder( $global_settings, $calculator_setting, $list_settings ),
				),
			);

			$cbcurrencyconverter_calculator_settings = array(
				'cbcurrencyconverter_enabledcurrencies_calculator' => array(
					'name'    => 'cbcurrencyconverter_enabledcurrencies_calculator',
					'label'   => esc_html__( 'Enable Currencies', 'cbcurrencyconverter' ),
					'desc'    => esc_html__( 'Currency list to convert and show in Calculator Dropdown', 'cbcurrencyconverter' ),
					'type'    => 'multiselect',
					'default' => array( 'USD', 'GBP', 'CAD', 'AUD' ),
					'options' => $all_currencies,
				),
				'cbcurrencyconverter_fromcurrency'                 => array(
					'name'    => 'cbcurrencyconverter_fromcurrency',
					'label'   => esc_html__( 'From', 'cbcurrencyconverter' ),
					'desc'    => esc_html__( 'What Will Be Your Default  Currency To Convert From', 'cbcurrencyconverter' ),
					'type'    => 'select',
					'default' => 'USD',
					'options' => $cal_from_to_list_currency,
				),
				'cbcurrencyconverter_tocurrency'                   => array(
					'name'    => 'cbcurrencyconverter_tocurrency',
					'label'   => esc_html__( 'To', 'cbcurrencyconverter' ),
					'desc'    => esc_html__( 'What Will Be Your Default To  Currency', 'cbcurrencyconverter' ),
					'type'    => 'select',
					'default' => 'CAD',
					'options' => $cal_from_to_list_currency,
				),
				'cbcurrencyconverter_defaultamount_for_calculator' => array(
					'name'    => 'cbcurrencyconverter_defaultamount_for_calculator',
					'label'   => esc_html__( 'Default Amount', 'cbcurrencyconverter' ),
					'desc'    => esc_html__( 'What Will Be Your Default Amount of Currency For Calculating', 'cbcurrencyconverter' ),
					'type'    => 'number',
					'default' => '1',

				),

				'cbcurrencyconverter_title_cal' => array(
					'name'    => 'cbcurrencyconverter_title_cal',
					'label'   => esc_html__( 'Calculator Heading', 'cbcurrencyconverter' ),
					'desc'    => esc_html__( 'Title to show in calculator', 'cbcurrencyconverter' ),
					'type'    => 'text',
					'default' => esc_html__( 'Currency Calculator', 'cbcurrencyconverter' ),
				),
			);


			$cbcurrencyconverter_list_settings = array(
				array(
					'name'    => 'cbcurrencyconverter_defaultcurrency_list',
					'label'   => esc_html__( 'From Currency', 'cbcurrencyconverter' ),
					'desc'    => esc_html__( 'What Will Be Your Default Currency For Listing', 'cbcurrencyconverter' ),
					'type'    => 'select',
					'default' => 'USD',
					'options' => $all_currencies,
				),
				array(
					'name'    => 'cbcurrencyconverter_tocurrency_list',
					'label'   => esc_html__( 'To Currency', 'cbcurrencyconverter' ),
					'desc'    => esc_html__( 'Currency list to convert and show in listing', 'cbcurrencyconverter' ),
					'type'    => 'multiselect',
					'default' => array( 'GBP', 'CAD', 'AUD' ),
					'options' => $all_currencies,
				),
				array(
					'name'    => 'cbcurrencyconverter_defaultamount_forlist',
					'label'   => esc_html__( 'Default Amount', 'cbcurrencyconverter' ),
					'desc'    => esc_html__( 'Default amount for listing', 'cbcurrencyconverter' ),
					'type'    => 'number',
					'default' => 1,
				),
				array(
					'name'    => 'cbcurrencyconverter_decimalpoint',
					'label'   => esc_html__( 'Decimal Point', 'cbcurrencyconverter' ),
					'desc'    => esc_html__( 'Decimal point position', 'cbcurrencyconverter' ),
					'type'    => 'number',
					'default' => '2',

				),
				array(
					'name'    => 'cbcurrencyconverter_title_list',
					'label'   => esc_html__( 'List Heading', 'cbcurrencyconverter' ),
					'desc'    => esc_html__( 'Title to show in listing', 'cbcurrencyconverter' ),
					'type'    => 'text',
					'default' => esc_html__( 'List of Currency', 'cbcurrencyconverter' ),
				),
			);

			$cbcurrencyconverter_tools = array(
				'cbcurrencyconverter_delete_options' => array(
					'name'    => 'cbcurrencyconverter_delete_options',
					'label'   => esc_html__( 'Remove Data on Uninstall?', 'cbcurrencyconverter' ),
					'desc'    => __( 'Check this box if you would like <strong>CBX Currency Converter</strong> to completely remove all of its data when the plugin is deleted.', 'cbcurrencyconverter' ),
					'type'    => 'checkbox',
					'default' => '',

				),
				'reset_data'                         => array(
					'name'     => 'reset_data',
					'label'    => esc_html__( 'Reset all data', 'cbcurrencyconverter' ),
					'desc'     => sprintf( __( 'Reset option values created by this plugin. 
<a class="button button-primary" onclick="return confirm(\'%s\')" href="%s">Reset Data</a>',
							'cbcurrencyconverter' ),
							esc_html__( 'Are you sure to reset all data, this process can not be undone?', 'cbcurrencyconverter' ),
							$reset_data_link ) . $table_html,
					'type'     => 'html',
					'default'  => '',
					'desc_tip' => true,
				),
				'reset_transient'                    => array(
					'name'     => 'reset_transient',
					'label'    => esc_html__( 'Reset Currency Rate Cache', 'cbcurrencyconverter' ),
					'desc'     => sprintf( __( 'Api request are stored as wordpress transient cache.<a class="button button-primary" onclick="return confirm(\'%s\')" href="%s">Reset transient cache</a>',
							'cbcurrencyconverter' ),
							esc_html__( 'Are you sure to reset currency rate cache, this process can not be undone?', 'cbcurrencyconverter' ),
							$reset_transient_link ) . $transient_table_html,
					'type'     => 'html',
					'default'  => '',
					'desc_tip' => true,
				),
			);

			$fields = array(
				'cbcurrencyconverter_global_settings'     => $cbcurrencyconverter_global_settings,
				'cbcurrencyconverter_calculator_settings' => $cbcurrencyconverter_calculator_settings,
				'cbcurrencyconverter_list_settings'       => $cbcurrencyconverter_list_settings,
				'cbcurrencyconverter_tools'               => $cbcurrencyconverter_tools,
			);

			return apply_filters( 'cbcurrencyconverter_fields', $fields );
		}//end get_settings_fields

		/**
		 * Full plugin reset and redirect
		 */
		public function plugin_fullreset() {
			global $wpdb;

			$option_prefix = 'cbcurrencyconverter_';

			$option_values = CBCurrencyConverterHelper::getAllOptionNames();

			foreach ( $option_values as $option_value ) {
				delete_option( $option_value['option_name'] );
			}

			do_action( 'cbcurrencyconverter_plugin_option_delete' );


			// create plugin's core table tables
			activate_cbcurrencyconverter();

			//please note that, the default options will be created by default

			//3rd party plugin's table creation
			do_action( 'cbcurrencyconverter_plugin_reset', $option_prefix );


			$this->settings_api->set_sections( $this->get_settings_sections() );
			$this->settings_api->set_fields( $this->get_settings_fields() );
			$this->settings_api->admin_init();

			set_transient( 'cbcurrencyconverter_fullreset_notice', 1 );

			wp_safe_redirect( admin_url( 'options-general.php?page=cbcurrencyconverter#cbcurrencyconverter_tools' ) );
			exit();
		}//end plugin_fullreset

		/**
		 * Delete transients created by this plugin and then redirect
		 */
		public function plugin_transientreset() {
			global $wpdb;

			$option_prefix = 'cbcurrencyconverter_';

			$transient_caches = CBCurrencyConverterHelper::getAllTransientCacheNames();

			foreach ( $transient_caches as $names ) {
				delete_transient( $names );
			}

			set_transient( 'cbcurrencyconverter_transientreset_notice', 1 );

			wp_safe_redirect( admin_url( 'options-general.php?page=cbcurrencyconverter#cbcurrencyconverter_tools' ) );
			exit();
		}//end plugin_transientreset


		/**
		 * Add setting link in plugin listing
		 *
		 * @param $links
		 *
		 * @return array
		 */
		public function action_links( $links ) {
			$new_links['settings'] = '<a style="color: #fb4e24; font-weight: bold;" href="' . admin_url( 'options-general.php?page=cbcurrencyconverter' ) . '">' . esc_html__( 'Settings', 'cbcurrencyconverter' ) . '</a>';

			return array_merge( $new_links, $links );
		}//end action_links

		/**
		 * Add Pro product link in plugin listing
		 *
		 * @param $links
		 * @param $file
		 *
		 * @return array
		 */
		public function custom_plugin_row_meta( $links, $file ) {
			if ( strpos( $file, 'cbcurrencyconverter.php' ) !== false ) {
				$new_links = array(
					'pro' => '<a style="color: #fb4e24; font-weight: bold;" href="https://codeboxr.com/product/cbx-currency-converter-for-wordpress/" target="_blank">' . esc_html__( 'Try Pro Addon', 'cbcurrencyconverter' ) . '</a>',
					'documentation' => '<a style="color: #fb4e24; font-weight: bold;" href="https://codeboxr.com/documentation-for-cbx-currency-converter-for-wordpress/" target="_blank">' . esc_html__( 'Documentation', 'cbcurrencyconverter' ) . '</a>'
				);

				$links = array_merge( $links, $new_links );
			}

			return $links;
		}//end custom_plugin_row_meta

		/**
		 * If we need to do something in upgrader process is completed
		 *
		 * @param $upgrader_object
		 * @param $options
		 */
		public function plugin_upgrader_process_complete( $upgrader_object, $options ) {
			if ( $options['action'] == 'update' && $options['type'] == 'plugin' ) {
				foreach ( $options['plugins'] as $each_plugin ) {
					if ( $each_plugin == CBCURRENCYCONVERTER_BASE_NAME ) {
						set_transient( 'cbcurrencyconverter_upgraded_notice', 1 );
						break;
					}
				}
			}

		}//end plugin_upgrader_process_complete

		/**
		 * Show a notice to anyone who has just installed the plugin for the first time
		 * This notice shouldn't display to anyone who has just updated this plugin
		 */
		public function plugin_activate_upgrade_notices() {
			//delete transient for cache delete notice if any
			if ( get_transient( 'cbcurrencyconverter_transientreset_notice' ) ) {
				echo '<div style="border-left-color:#fb4e24;" class="notice notice-success is-dismissible">';
				echo '<p style="color: #fb4e24;">' . esc_html__( 'Currency rate cache has been reset', 'cbcurrencyconverter' ) . '</p>';
				echo '</div>';

				delete_transient( 'cbcurrencyconverter_transientreset_notice' );
			}

			//delete transient for full reset notice if any
			if ( get_transient( 'cbcurrencyconverter_fullreset_notice' ) ) {
				echo '<div style="border-left-color:#fb4e24;" class="notice notice-success is-dismissible">';
				echo '<p style="color: #fb4e24;">' . esc_html__( 'CBX Currency Converter plugin setting has been reset to defaults', 'cbcurrencyconverter' ) . '</p>';
				echo '</div>';

				delete_transient( 'cbcurrencyconverter_fullreset_notice' );
			}


			// Check the transient to see if we've just activated the plugin
			if ( get_transient( 'cbcurrencyconverter_activated_notice' ) ) {
				echo '<div style="border-left-color:#fb4e24;" class="notice notice-success is-dismissible">';
				echo '<p><img style="float: left; display: inline-block; margin-right: 15px;" src="' . CBCURRENCYCONVERTER_ROOT_URL . 'assets/images/icon_48.png' . '"/>' . sprintf( __( 'Thanks for installing/deactivating <strong>CBX Currency Converter</strong> V%s - Codeboxr Team', 'cbcurrencyconverter' ), CBCURRENCYCONVERTER_VERSION ) . '</p>';
				echo '<p>' . sprintf( __( 'Check <a style="color: #fb4e24;" href="%s">Plugin Setting</a> | <a href="%s" target="_blank">Documentation</a>', 'cbcurrencyconverter' ), admin_url( 'options-general.php?page=cbcurrencyconverter' ), 'https://codeboxr.com/product/cbx-currency-converter-for-wordpress/' ) . '</p>';
				echo '</div>';
				// Delete the transient so we don't keep displaying the activation message
				delete_transient( 'cbcurrencyconverter_activated_notice' );

				$this->pro_addon_compatibility_campaign();

			}

			// Check the transient to see if we've just activated the plugin
			if ( get_transient( 'cbcurrencyconverter_upgraded_notice' ) ) {
				echo '<div style="border-left-color:#fb4e24;" class="notice notice-success is-dismissible">';
				echo '<p><img style="float: left; display: inline-block; margin-right: 15px;" src="' . CBCURRENCYCONVERTER_ROOT_URL . 'assets/images/icon_48.png' . '"/>' . sprintf( __( 'Thanks for upgrading <strong>CBX Currency Converter</strong> V%s , enjoy the new features and bug fixes - Codeboxr Team', 'cbcurrencyconverter' ), CBCURRENCYCONVERTER_VERSION ) . '</p>';
				echo '<p>' . sprintf( __( 'Check <a href="%s" style="color: #fb4e24;" >Plugin Setting</a> | <a href="%s" target="_blank">Documentation</a>', 'cbcurrencyconverter' ), admin_url( 'options-general.php?page=cbcurrencyconverter' ), 'https://codeboxr.com/product/cbx-currency-converter-for-wordpress/' ) . '</p>';
				echo '</div>';
				// Delete the transient so we don't keep displaying the activation message
				delete_transient( 'cbcurrencyconverter_upgraded_notice' );

				$this->pro_addon_compatibility_campaign();

			}
		}//end plugin_activate_upgrade_notices

		/**
		 * Check plugin compatibility and pro addon install campaign
		 */
		public function pro_addon_compatibility_campaign() {

			if ( ! function_exists( 'is_plugin_active' ) ) {
				include_once( ABSPATH . 'wp-admin/includes/plugin.php' );
			}

			//if the pro addon is active or installed
			if ( in_array( 'cbcurrencyconverteraddon/cbcurrencyconverteraddon.php', apply_filters( 'active_plugins', get_option( 'active_plugins' ) ) ) || defined( 'CBCURRENCYCONVERTERADDON_NAME' ) ) {
				//plugin is activated

				$plugin_version = CBCURRENCYCONVERTERADDON_VERSION;


			} else {
				echo '<div style="border-left-color:#fb4e24;" class="notice notice-success is-dismissible"><p>' . sprintf( __( '<a target="_blank" href="%s">CBX Currency Converter Pro Addon</a> has extended features, settings, widgets and shortcodes. try it  - Codeboxr Team', 'cbcurrencyconverter' ), 'https://codeboxr.com/product/cbx-currency-converter-for-wordpress/' ) . '</p></div>';
			}
		}//end pro_addon_compatibility_campaign

		/**
		 * Init all gutenberg blocks
		 */
		public function gutenberg_blocks() {
			$setting_global = get_option( 'cbcurrencyconverter_global_settings' );
			$setting_list   = get_option( 'cbcurrencyconverter_list_settings' );
			$setting_cal    = get_option( 'cbcurrencyconverter_calculator_settings' );

			//get default values from global settings

			//general setting
			$layout       = ( isset( $setting_global['cbcurrencyconverter_defaultlayout'] ) ) ? sanitize_text_field( $setting_global['cbcurrencyconverter_defaultlayout'] ) : 'cal';
			$decimalpoint = ( isset( $setting_global['cbcurrencyconverter_decimalpoint'] ) ) ? intval( $setting_global['cbcurrencyconverter_decimalpoint'] ) : 2;

			//calculator setting
			$calc_currencies     = ( isset( $setting_cal['cbcurrencyconverter_enabledcurrencies_calculator'] ) ) ? wp_unslash( $setting_cal['cbcurrencyconverter_enabledcurrencies_calculator'] ) : array( 'USD', 'GBP', 'CAD', 'AUD' );
			$calc_from_currency  = ( isset( $setting_cal['cbcurrencyconverter_fromcurrency'] ) ) ? sanitize_text_field( $setting_cal['cbcurrencyconverter_fromcurrency'] ) : 'USD';
			$calc_to_currency    = ( isset( $setting_cal['cbcurrencyconverter_tocurrency'] ) ) ? sanitize_text_field( $setting_cal['cbcurrencyconverter_tocurrency'] ) : 'CAD';
			$calc_default_amount = ( isset( $setting_cal['cbcurrencyconverter_defaultamount_for_calculator'] ) ) ? floatval( $setting_cal['cbcurrencyconverter_defaultamount_for_calculator'] ) : 1;
			$calc_title          = ( isset( $setting_cal['cbcurrencyconverter_title_cal'] ) ) ? sanitize_text_field( $setting_cal['cbcurrencyconverter_title_cal'] ) : esc_html__( 'Currency Calculator', 'cbcurrencyconverter' );

			//list setting
			$list_from_currency  = ( isset( $setting_list['cbcurrencyconverter_defaultcurrency_list'] ) ) ? sanitize_text_field( $setting_list['cbcurrencyconverter_defaultcurrency_list'] ) : 'USD'; //we need to set something as default currency to make the list work
			$list_to_currency    = ( isset( $setting_list['cbcurrencyconverter_tocurrency_list'] ) ) ? wp_unslash( $setting_list['cbcurrencyconverter_tocurrency_list'] ) : array( 'GBP', 'CAD', 'AUD' ); //list of currency
			$list_default_amount = ( isset( $setting_list['cbcurrencyconverter_defaultamount_forlist'] ) ) ? floatval( $setting_list['cbcurrencyconverter_defaultamount_forlist'] ) : 1; //default amount
			$list_title          = ( isset( $setting_list['cbcurrencyconverter_title_list'] ) ) ? sanitize_text_field( $setting_list['cbcurrencyconverter_title_list'] ) : esc_html__( 'List of Currency', 'cbcurrencyconverter' ); //list title


			$layouts         = CBCurrencyConverterHelper::get_layouts();
			$layouts_options = array();
			foreach ( $layouts as $key => $value ) {
				$layouts_options[] = array(
					'label' => esc_attr( $value ),
					'value' => esc_attr( $key ),
				);
			}


			$all_currencies = CBCurrencyConverterHelper::getCurrencyList();


			if ( isset( $calc_currencies ) && ! empty( $calc_currencies ) ) {
				foreach ( $all_currencies as $key => $value ) {
					if ( ! in_array( $key, $calc_currencies ) ) {
						unset( $all_currencies[ $key ] );
					}
				}
			}

			$calc_currencies_options = array();
			foreach ( $all_currencies as $key => $value ) {
				$calc_currencies_options[] = array(
					'label' => esc_attr( $value . ' - ' . $key ),
					'value' => esc_attr( $key ),
				);
			}


			$all_currencies = CBCurrencyConverterHelper::getCurrencyList();

			$all_currencies_options = array();

			foreach ( $all_currencies as $key => $value ) {
				$all_currencies_options[] = array(
					'label' => esc_attr( $value . ' - ' . $key ),
					'value' => esc_attr( $key ),
				);
			}

			//wp_register_script( 'select2', plugin_dir_url( __FILE__ ) . '../assets/js/select2/js/select2.min.js', array( 'jquery' ), $this->version, true );

			//wp_register_script( 'cbcurrencyconverter-public',plugin_dir_url( __FILE__ ) . '../assets/js/cbcurrencyconverter-public.js',	array('jquery',			'select2'),$this->version,	true );

			wp_register_script( 'cbcurrencyconverter-block',
				plugin_dir_url( __FILE__ ) . '../assets/js/cbcurrencyconverter-block.js',
				array(
					//'select2',
					//'cbcurrencyconverter-public',
					'wp-blocks',
					'wp-element',
					'wp-components',
					'wp-editor',
				),
				filemtime( plugin_dir_path( __FILE__ ) . '../assets/js/cbcurrencyconverter-block.js' ) );


			wp_register_style( 'select2',
				plugin_dir_url( __FILE__ ) . '../assets/js/select2/css/select2.min.css',
				array(),
				$this->version );
			wp_register_style( 'cbcurrencyconverter-public', plugin_dir_url( __FILE__ ) . '../assets/css/cbcurrencyconverter-public.css', array( 'select2' ), $this->version, 'all' );

			wp_register_style( 'cbcurrencyconverter-block', plugin_dir_url( __FILE__ ) . '../assets/css/cbcurrencyconverter-block.css', array( 'select2', 'cbcurrencyconverter-public' ), filemtime( plugin_dir_path( __FILE__ ) . '../assets/css/cbcurrencyconverter-block.css' ) );

			$js_vars = apply_filters( 'cbcurrencyconverter_block_js_vars',
				array(
					'block_title'         => esc_html__( 'CBX Currency Converter', 'cbcurrencyconverter' ),
					'block_category'      => 'codeboxr',
					'block_icon'          => 'universal-access-alt',
					'block_icon_url'      => plugin_dir_url( __FILE__ ) . '../assets/images/dollar.svg',
					'general_settings'    => array(
						'title'          => esc_html__( 'CBX Currency Converter', 'cbcurrencyconverter' ),
						'layout'         => esc_html__( 'Select Layout', 'cbcurrencyconverter' ),
						'layout_options' => $layouts_options,
						'decimalpoint'   => esc_html__( 'Decimal Point', 'cbcurrencyconverter' )
					),
					'calculator_settings' => array(
						'title'                   => esc_html__( 'Calculator settings', 'cbcurrencyconverter' ),
						'calc_title'              => esc_html__( 'Calculator Header', 'cbcurrencyconverter' ),
						'calc_currencies'         => esc_html__( 'Calculator Enabled Currencies', 'cbcurrencyconverter' ),
						'calc_currencies_options' => $calc_currencies_options,
						'calc_from_currency'      => esc_html__( 'Calculator From Currency', 'cbcurrencyconverter' ),
						'calc_to_currency'        => esc_html__( 'Calculator To Currency', 'cbcurrencyconverter' ),
						'calc_default_amount'     => esc_html__( 'Default Amount for Calculator', 'cbcurrencyconverter' )
					),
					'list_settings' => array(
						'title'                  => esc_html__( 'List settings', 'cbcurrencyconverter' ),
						'list_title'             => esc_html__( 'List Header', 'cbcurrencyconverter' ),
						'list_from_currency'     => esc_html__( 'List From Currency', 'cbcurrencyconverter' ),
						'list_to_currency'       => esc_html__( 'List To Currencies', 'cbcurrencyconverter' ),
						'all_currencies_options' => $all_currencies_options,
						'list_default_amount'    => esc_html__( 'Default Amount for Calculator', 'cbcurrencyconverter' ),
					),
				) );

			wp_localize_script( 'cbcurrencyconverter-block', 'cbcurrencyconverter_block', $js_vars );

			register_block_type( 'codeboxr/cbcurrencyconverter',
				array(
					'editor_script'   => 'cbcurrencyconverter-block',
					'editor_style'    => 'cbcurrencyconverter-block',
					'attributes'      => apply_filters( 'cbcurrencyconverter_block_attributes',
						array(
							//general
							'layout'              => array(
								'type'    => 'string',
								'default' => $layout,
							),
							'decimalpoint'        => array(
								'type'    => 'integer',
								'default' => $decimalpoint,
							),
							'calc_title'          => array(
								'type'    => 'string',
								'default' => $calc_title,
							),
							'calc_currencies'     => array(
								'type'    => 'array',
								'default' => $calc_currencies,
								'items'   => array(
									'type' => 'string'
								)
							),
							'calc_from_currency'  => array(
								'type'    => 'string',
								'default' => $calc_from_currency,
							),
							'calc_to_currency'    => array(
								'type'    => 'string',
								'default' => $calc_to_currency,
							),
							'calc_default_amount' => array(
								'type'    => 'number',
								'default' => $calc_default_amount,
							),
							'list_title'          => array(
								'type'    => 'string',
								'default' => $list_title,
							),
							'list_from_currency'  => array(
								'type'    => 'string',
								'default' => $list_from_currency,
							),
							'list_to_currency'    => array(
								'type'    => 'array',
								'default' => $list_to_currency,
								'items'   => array(
									'type' => 'string'
								)
							),
							'list_default_amount' => array(
								'type'    => 'number',
								'default' => $list_default_amount,
							)

						) ),
					'render_callback' => array( $this, 'cbcurrencyconverter_block_render' ),
				) );

		}//end gutenberg_blocks

		/**
		 * Getenberg server side render
		 *
		 * @param $settings
		 *
		 * @return string
		 */
		public function cbcurrencyconverter_block_render( $attributes ) {
			$setting_global = get_option( 'cbcurrencyconverter_global_settings' );
			$setting_list   = get_option( 'cbcurrencyconverter_list_settings' );
			$setting_cal    = get_option( 'cbcurrencyconverter_calculator_settings' );

			//get default values from global settings

			//general setting
			$layout       = ( isset( $setting_global['cbcurrencyconverter_defaultlayout'] ) ) ? sanitize_text_field( $setting_global['cbcurrencyconverter_defaultlayout'] ) : 'cal';
			$decimalpoint = ( isset( $setting_global['cbcurrencyconverter_decimalpoint'] ) ) ? intval( $setting_global['cbcurrencyconverter_decimalpoint'] ) : 2;

			//calculator setting
			$calc_currencies     = ( isset( $setting_cal['cbcurrencyconverter_enabledcurrencies_calculator'] ) ) ? wp_unslash( $setting_cal['cbcurrencyconverter_enabledcurrencies_calculator'] ) : array( 'USD', 'GBP', 'CAD', 'AUD' );
			$calc_from_currency  = ( isset( $setting_cal['cbcurrencyconverter_fromcurrency'] ) ) ? sanitize_text_field( $setting_cal['cbcurrencyconverter_fromcurrency'] ) : 'USD';
			$calc_to_currency    = ( isset( $setting_cal['cbcurrencyconverter_tocurrency'] ) ) ? sanitize_text_field( $setting_cal['cbcurrencyconverter_tocurrency'] ) : 'CAD';
			$calc_default_amount = ( isset( $setting_cal['cbcurrencyconverter_defaultamount_for_calculator'] ) ) ? floatval( $setting_cal['cbcurrencyconverter_defaultamount_for_calculator'] ) : 1;
			$calc_title          = ( isset( $setting_cal['cbcurrencyconverter_title_cal'] ) ) ? sanitize_text_field( $setting_cal['cbcurrencyconverter_title_cal'] ) : esc_html__( 'Currency Calculator', 'cbcurrencyconverter' );

			//list setting
			$list_from_currency  = ( isset( $setting_list['cbcurrencyconverter_defaultcurrency_list'] ) ) ? sanitize_text_field( $setting_list['cbcurrencyconverter_defaultcurrency_list'] ) : 'USD'; //we need to set something as default currency to make the list work
			$list_to_currency    = ( isset( $setting_list['cbcurrencyconverter_tocurrency_list'] ) ) ? wp_unslash( $setting_list['cbcurrencyconverter_tocurrency_list'] ) : array( 'GBP', 'CAD', 'AUD' ); //list of currency
			$list_default_amount = ( isset( $setting_list['cbcurrencyconverter_defaultamount_forlist'] ) ) ? floatval( $setting_list['cbcurrencyconverter_defaultamount_forlist'] ) : 1; //default amount
			$list_title          = ( isset( $setting_list['cbcurrencyconverter_title_list'] ) ) ? sanitize_text_field( $setting_list['cbcurrencyconverter_title_list'] ) : esc_html__( 'List of Currency', 'cbcurrencyconverter' ); //list title

			$atts = array();


			$atts['layout']       = isset( $attributes['layout'] ) ? sanitize_text_field( $attributes['layout'] ) : $layout;
			$atts['decimalpoint'] = isset( $attributes['decimalpoint'] ) ? intval( $attributes['decimalpoint'] ) : $decimalpoint;


			//calculator setting
			$atts['calc_title']      = isset( $attributes['calc_title'] ) ? sanitize_text_field( $attributes['calc_title'] ) : $calc_title;
			$atts['calc_currencies'] = isset( $attributes['calc_currencies'] ) ? wp_unslash( $attributes['calc_currencies'] ) : $calc_currencies;

			$atts['calc_from_currency']  = isset( $attributes['calc_from_currency'] ) ? sanitize_text_field( $attributes['calc_from_currency'] ) : $calc_from_currency;
			$atts['calc_to_currency']    = isset( $attributes['calc_to_currency'] ) ? sanitize_text_field( $attributes['calc_to_currency'] ) : $calc_to_currency;
			$atts['calc_default_amount'] = isset( $attributes['calc_default_amount'] ) ? floatval( $attributes['calc_default_amount'] ) : $calc_default_amount;


			//list setting
			$atts['list_title']         = isset( $attributes['list_title'] ) ? sanitize_text_field( $attributes['list_title'] ) : $list_title;
			$atts['list_from_currency'] = isset( $attributes['list_from_currency'] ) ? sanitize_text_field( $attributes['list_from_currency'] ) : $list_from_currency;
			$atts['list_to_currency']   = isset( $attributes['list_to_currency'] ) ? wp_unslash( $attributes['list_to_currency'] ) : $list_to_currency;

			$atts['list_default_amount'] = isset( $attributes['list_default_amount'] ) ? floatval( $attributes['list_default_amount'] ) : $list_default_amount;

			$atts['calc_currencies']  = implode( ',', $atts['calc_currencies'] );
			$atts['list_to_currency'] = implode( ',', $atts['list_to_currency'] );

			$attr_html = '';

			foreach ( $atts as $key => $value ) {
				$attr_html .= ' ' . $key . '="' . $value . '" ';
			}

			return do_shortcode( '[cbcurrencyconverter ' . $attr_html . ']' );

		}//end cbcurrencyconverter_block_render

		/**
		 * Register New Gutenberg block Category if need
		 *
		 * @param $categories
		 * @param $post
		 *
		 * @return mixed
		 */
		public function gutenberg_block_categories( $categories, $post ) {
			$found = false;

			foreach ( $categories as $category ) {
				if ( $category['slug'] == 'codeboxr' ) {
					$found = true;
					break;
				}
			}

			if ( ! $found ) {
				return array_merge(
					$categories,
					array(
						array(
							'slug'  => 'codeboxr',
							'title' => esc_html__( 'CBX Blocks', 'cbcurrencyconverter' ),
							//'icon'  => 'wordpress',
						),
					)
				);
			}

			return $categories;
		}//end gutenberg_block_categories


		/**
		 * Enqueue style for block editor
		 */
		public function enqueue_block_editor_assets() {

		}//end enqueue_block_editor_assets

        /**
         * Add our self-hosted autoupdate plugin to the filter transient
         *
         * @param $transient
         *
         * @return object $ transient
         */
        public function pre_set_site_transient_update_plugins_pro_addon($transient){
            // Extra check for 3rd plugins
            if ( isset( $transient->response[ 'cbcurrencyconverteraddon/cbcurrencyconverteraddon.php' ] ) ) {
                return $transient;
            }

            if ( ! function_exists( 'get_plugins' ) ) {
                require_once ABSPATH . 'wp-admin/includes/plugin.php';
            }

            $plugin_info = array();
            $all_plugins = get_plugins();
            if(!isset($all_plugins['cbcurrencyconverteraddon/cbcurrencyconverteraddon.php'])){
                return $transient;
            }
            else{
                $plugin_info = $all_plugins['cbcurrencyconverteraddon/cbcurrencyconverteraddon.php'];
            }

            $remote_version = '1.6.6';

            if ( version_compare( $plugin_info['Version'], $remote_version, '<' ) ) {
                $obj = new stdClass();
                $obj->slug = 'cbcurrencyconverteraddon';
                $obj->new_version = $remote_version;
                $obj->plugin = 'cbcurrencyconverteraddon/cbcurrencyconverteraddon.php';
                $obj->url = '';
                $obj->package = false;
                $obj->name = 'CBX Currency Converter Pro Addon';
                $transient->response[ 'cbcurrencyconverteraddon/cbcurrencyconverteraddon.php' ] = $obj;
            }

            return $transient;
        }//end pre_set_site_transient_update_plugins_pro_addons


        /**
         * Pro Addon update message
         */
        public function plugin_update_message_pro_addons(){
            echo ' '.sprintf(__('Check how to <a style="color:#9c27b0 !important; font-weight: bold;" href="%s"><strong>Update manually</strong></a> , download latest version from <a style="color:#9c27b0 !important; font-weight: bold;" href="%s"><strong>My Account</strong></a> section of Codeboxr.com', 'cbcurrencyconverter'), 'https://codeboxr.com/manual-update-pro-addon/', 'https://codeboxr.com/my-account/');
        }//end plugin_update_message_pro_addons

	}//end class CBCurrencyConverter_Admin
