<?php
// If this file is called directly, abort.
if ( ! defined( 'WPINC' ) ) {
	die;
}


/**
 * Class CBCurrencyConverterHelper
 *
 * @since  2.2
 */
class CBCurrencyConverterHelper {
    /**
     * Currency rates api methods
     */
    public static function currency_rates_api(){
        $rates_api = array();

        $rates_api['alphavantage'] = array(
            'title' => esc_html__('Alphavantage.co', 'cbcurrencyconverter'),
            'class' => 'CBCurrencyConverterAlphavantage',
            'method' => 'api_method',
        );

        $rates_api['openexchangerates_free'] = array(
            'title' => esc_html__('Openexchangerates.org Free Plan(only base USD)', 'cbcurrencyconverter'),
            'class' => 'CBCurrencyConverterOpenexchangeratesFree',
            'method' => 'api_method',
        );

        $rates_api['currencylayer_free'] = array(
            'title' => esc_html__('Currencylayer.com Free Plan(only base USD)', 'cbcurrencyconverter'),
            'class' => 'CBCurrencyConverterCurrencyLayerFree',
            'method' => 'api_method',
        );

        return apply_filters('cbcurrencyconverter_rates_apis', $rates_api);
    }//end currency_rates_api

    /**
     * Currency rates api methods titles
     */
    public static function currency_rates_api_titles(){
        $rates_api = CBCurrencyConverterHelper::currency_rates_api();

        $rates_api_titles = array();

        foreach ($rates_api as $key => $api){
            $rates_api_titles[$key] = $api['title'];
        }

        return apply_filters('cbcurrencyconverter_rates_api_titles', $rates_api_titles);
    }//end currency_rates_api_titles

    /**
     * alphavantage.co api method
     *
     * @since 2.8.0
     *
     * @param     $convertion_value
     * @param     $price
     * @param     $convertfrom
     * @param     $convertto
     * @param int $decimalpoint
     *
     * @return string
     */
    public static function alphavantage_api_method( $convertion_value = 0, $price, $convertfrom, $convertto, $decimalpoint = 2 ) {

        $setting = new CBCurrencyconverterSetting();

        $cache         = intval( $setting->get_option( 'cbcurrencyconverter_ratecache', 'cbcurrencyconverter_global_settings', 1 ) ); //from version 2.7.1
        $cache_time_hr = intval( $setting->get_option( 'cbcurrencyconverter_cachetime', 'cbcurrencyconverter_global_settings', 2 ) ); //from version 2.7.1

        if ( $cache ) {
            // Get any existing copy of our transient data
            if ( false === ( $convertion_cache = get_transient( 'cbcurrencyconverter_alphavantage' ) ) ) {
                $convertion_cache                                    = array();
                $convertion_value                                    = CBCurrencyConverterHelper::alphavantage_api_get( $convertfrom, $convertto );
                $convertion_cache[ $convertfrom . '-' . $convertto ] = $convertion_value;
                $convertion_cache                                    = maybe_serialize( $convertion_cache );

                //https://codex.wordpress.org/Transients_API
                set_transient( 'cbcurrencyconverter_alphavantage', $convertion_cache, $cache_time_hr * HOUR_IN_SECONDS );

                $convertion_value = $convertion_value * $price;
                $convertion_value = apply_filters( 'cbcurrencyconverter_rate_final', $convertion_value, $price, $convertfrom, $convertto, $decimalpoint );

                return number_format_i18n( $convertion_value, $decimalpoint );
            }

            $convertion_cache = maybe_unserialize( $convertion_cache );
            if ( isset( $convertion_cache[ $convertfrom . '-' . $convertto ] ) ) {
                $convertion_value = $convertion_cache[ $convertfrom . '-' . $convertto ];
            } else {
                $convertion_value                                    = CBCurrencyConverterHelper::alphavantage_api_get( $convertfrom, $convertto );
                $convertion_cache[ $convertfrom . '-' . $convertto ] = $convertion_value;
                $convertion_cache                                    = maybe_serialize( $convertion_cache );

                //https://codex.wordpress.org/Transients_API
                set_transient( 'cbcurrencyconverter_alphavantage', $convertion_cache, $cache_time_hr * HOUR_IN_SECONDS );
            }
        } else {
            $convertion_value = CBCurrencyConverterHelper::alphavantage_api_get( $convertfrom, $convertto );
        }


        //return number_format_i18n( ( $convertion_value * $price ), $decimalpoint );
        //return number_format_i18n( ( $convertion_value * $price ), $decimalpoint );

        $convertion_value = $convertion_value * $price;
        $convertion_value = apply_filters( 'cbcurrencyconverter_rate_final', $convertion_value, $price, $convertfrom, $convertto, $decimalpoint );

        return number_format_i18n( $convertion_value, $decimalpoint );
    }//end alphavantage_api_method

    /**
     * api request to alphavantage.co
     *
     * @since 2.8.0
     *
     * @param $convertfrom
     * @param $convertto
     *
     * @return int
     */
    public static function alphavantage_api_get( $convertfrom, $convertto ) {

        $setting = new CBCurrencyconverterSetting();
        $api_key = $setting->get_option( 'apikey', 'cbcurrencyconverter_global_settings', '' );

        if ( $api_key == '' ) {
            return 0;
        }


        $url = 'https://www.alphavantage.co/query?function=CURRENCY_EXCHANGE_RATE&from_currency=' . urlencode( $convertfrom ) . '&to_currency=' . urlencode( $convertto ) . '&apikey=' . $api_key;
        $ch  = curl_init();

        curl_setopt( $ch, CURLOPT_URL, $url );
        curl_setopt( $ch, CURLOPT_RETURNTRANSFER, 1 );
        curl_setopt( $ch, CURLOPT_HEADER, 0 );
        curl_setopt( $ch, CURLOPT_SSL_VERIFYPEER, false );
        $body = curl_exec( $ch );

        curl_close( $ch );

        $result = json_decode( $body, true );
        $result = array_values( $result );

        if ( is_array( $result[0] ) ) {
            $result        = array_values( $result[0] );
            $from_currency = $result[0];
            $to_currency   = $result[1];
            $value         = $result[4];

            return $value;
        }

        return 0;
    }//end alphavantage_api_get



    /**
     * Get display layouts
     *
     * @return mixed|void
     */
	public static function get_layouts() {
		$layout = array(
			'cal'               => esc_html__( 'Calculator', 'cbcurrencyconverter' ),
			'list'              => esc_html__( 'List', 'cbcurrencyconverter' ),
			'calwithlistbottom' => esc_html__( 'Calc with List Bottom', 'cbcurrencyconverter' ),
			'calwithlisttop'    => esc_html__( 'Calc with List Top', 'cbcurrencyconverter' ),
		);

		return apply_filters( 'cbcurrencyconverter_layout', $layout );
	}//end get_layouts

	/**
	 * Get available style reverser
	 *
	 * @return mixed|void
	 */
	public static function get_layouts_r() {
		$layout   = CBCurrencyConverterHelper::get_layouts();
		$layout_r = array();

		foreach ( $layout as $key => $value ) {
			$layout_r[ $value ] = $key;
		}

		return apply_filters( 'cbcurrencyconverter_layout_r', $layout_r );
	}//end get_styles_r

	/**
	 * List of all transient cache names used in this plugin
	 *
	 * @return array
	 */
	public static function getAllTransientCacheNames() {
		$transient_caches = array();

		$transient_caches[] = 'cbcurrencyconverter_alphavantage';
		$transient_caches[] = 'cbcurrencyconverter_openexchangeratesfree';
		$transient_caches[] = 'cbcurrencyconverter_currencylayerfree';



		return apply_filters( 'cbcurrencyconverter_transientname', $transient_caches );
	}//getAllTransientCacheNames

	/**
	 *
	 * @param       $cbcur_reference
	 * @param array $instance
	 *
	 * @return string
	 * @since  2.2
	 *
	 */
	public static function cbxcccalcview( $cbcur_reference, $instance = array() ) {

		extract( $instance );

		$decimalpoint                      = ( isset( $decimalpoint ) ) ? intval( $decimalpoint ) : 2;
		$cbcurrencyconverter_currency_list = CBCurrencyConverterHelper::getCurrencyList();

		//currency list for calculator
		if ( isset( $calc_currencies ) && is_array( $calc_currencies ) && sizeof( $calc_currencies ) > 0 ) {

			foreach ( $cbcurrencyconverter_currency_list as $key => $value ) {
				if ( ! in_array( $key, $calc_currencies ) ) {
					unset( $cbcurrencyconverter_currency_list[ $key ] );
				}
			}

		}

		//only for calculator

		$calc_title          = ( isset( $calc_title ) ) ? esc_attr( $calc_title ) : esc_html__( 'Currency Calculator', 'cbcurrencyconverter' );
		$calc_from_currency  = ( isset( $calc_from_currency ) ) ? esc_attr( $calc_from_currency ) : '';
		$calc_to_currency    = ( isset( $calc_to_currency ) ) ? esc_attr( $calc_to_currency ) : '';
		$calc_default_amount = ( isset( $calc_default_amount ) ) ? intval( $calc_default_amount ) : 1;


		if ( $cbcur_reference == 'shortcode' ) {
			//do any special processing for shortcode
		}

		if ( $cbcur_reference == 'widget' ) {
			//do any special processing for widget
		}

		ob_start();
		include( cbcurrencyconverter_locate_template( 'calculator.php' ) );
		$content = ob_get_contents();
		ob_end_clean();

		return $content;
	}//end of method cbxcccalcview

	/**
	 *
	 * @param       $cbcur_reference
	 * @param array $instance
	 *
	 * @return string
	 * @since  2.2
	 *
	 */
	public static function cbxcclistview( $cbcur_reference, $instance = array() ) {

		$CbCurrencyConverter = new CBCurrencyConverter_Public( CBCURRENCYCONVERTER_NAME, CBCURRENCYCONVERTER_VERSION );

		extract( $instance );


		$decimalpoint = ( isset( $decimalpoint ) ) ? intval( $decimalpoint ) : 2;

		$list_title         = ( isset( $list_title ) ) ? esc_attr( $list_title ) : esc_html__( 'List of Currency', 'cbcurrencyconverter' );
		$list_from_currency = ( isset( $list_from_currency ) ) ? esc_attr( $list_from_currency ) : 'USD';
		$list_to_currency   = ( isset( $list_to_currency ) ) ? $list_to_currency : array( 'GBP' );


		$list_default_amount = ( isset( $list_default_amount ) ) ? intval( $list_default_amount ) : 1;

		ob_start();
		include( cbcurrencyconverter_locate_template( 'list.php' ) );
		$content = ob_get_contents();
		ob_end_clean();

		return $content;
	}//end cbxcclistview

	/**
	 *
	 * @param       $cbcur_reference
	 * @param array $instance
	 *
	 * @return string
	 *
	 * @since  2.2
	 *
	 */
	public static function cbxcccalcinline( $cbcur_reference, $instance = array() ) {


		$CbCurrencyConverter = new CBCurrencyConverter();

		$setting_api      = get_option( 'cbcurrencyconverter_global_settings' );
		$setting_api_list = get_option( 'cbcurrencyconverter_list_settings' );
		$setting_api_cal  = get_option( 'cbcurrencyconverter_calculator_settings' );


		//general setting
		$layout       = ( isset( $setting_api['cbcurrencyconverter_defaultlayout'] ) ) ? $setting_api['cbcurrencyconverter_defaultlayout'] : 'cal';
		$decimalpoint = ( isset( $setting_api['cbcurrencyconverter_decimalpoint'] ) ) ? $setting_api['cbcurrencyconverter_decimalpoint'] : 2;


		//list setting
		$list_title          = ( isset( $setting_api_list['cbcurrencyconverter_title_list'] ) ) ? $setting_api_list['cbcurrencyconverter_title_list'] : esc_html__( 'List of Currency', 'cbcurrencyconverter' ); //list title
		$list_from_currency  = ( isset( $setting_api_list['cbcurrencyconverter_defaultcurrency_list'] ) ) ? $setting_api_list['cbcurrencyconverter_defaultcurrency_list'] : 'USD'; //we need to set something as default currency to make the list work
		$list_to_currency    = ( isset( $setting_api_list['cbcurrencyconverter_tocurrency_list'] ) ) ? $setting_api_list['cbcurrencyconverter_tocurrency_list'] : array( 'GBP' ); //list of currency
		$list_default_amount = ( isset( $setting_api_list['cbcurrencyconverter_defaultamount_forlist'] ) ) ? $setting_api_list['cbcurrencyconverter_defaultamount_forlist'] : 1; //default amount


		//calculator setting
		$calc_title          = ( isset( $setting_api_cal['cbcurrencyconverter_title_cal'] ) ) ? $setting_api_cal['cbcurrencyconverter_title_cal'] : esc_html__( 'Currency Calculator', 'cbcurrencyconverter' );
		$calc_from_currency  = ( isset( $setting_api_cal['cbcurrencyconverter_fromcurrency'] ) ) ? $setting_api_cal['cbcurrencyconverter_fromcurrency'] : '';
		$calc_to_currency    = ( isset( $setting_api_cal['cbcurrencyconverter_tocurrency'] ) ) ? $setting_api_cal['cbcurrencyconverter_tocurrency'] : '';
		$calc_default_amount = ( isset( $setting_api_cal['cbcurrencyconverter_defaultamount_for_calculator'] ) ) ? $setting_api_cal['cbcurrencyconverter_defaultamount_for_calculator'] : 1;
		$calc_currencies     = ( isset( $setting_api_cal['cbcurrencyconverter_enabledcurrencies_calculator'] ) ) ? $setting_api_cal['cbcurrencyconverter_enabledcurrencies_calculator'] : array_keys( CBCurrencyConverter::$cbcurrencyconverter_currency_list );


		// result


		$calc_from_currency  = isset( $instance['calc_from_currency'] ) ? $instance['calc_from_currency'] : $calc_from_currency;
		$calc_to_currency    = isset( $instance['calc_to_currency'] ) ? $instance['calc_to_currency'] : $calc_to_currency;
		$calc_default_amount = isset( $instance['calc_default_amount'] ) ? $instance['calc_default_amount'] : $calc_default_amount;
		$calc_title          = isset( $instance['calc_title'] ) ? $instance['calc_title'] : $calc_title;


		$cbcurrencyconverter_currency_list = CBCurrencyConverterHelper::getCurrencyList();

		if ( ! in_array( $calc_to_currency, $cbcurrencyconverter_currency_list ) ) {
			unset( $cbcurrencyconverter_currency_list[ $calc_to_currency ] );
		}


		ob_start();
		include( cbcurrencyconverter_locate_template( 'inline.php' ) );
		$content = ob_get_contents();
		ob_end_clean();

		return $content;
	}//end of method cbxcccalcinline

	/**
	 * Get all currency list
	 *
	 * @return mixed|void
	 * @since  2.2
	 *
	 */
	public static function getCurrencyList() {
		$currency_list = array(
			'AED' => __( 'United Arab Emirates dirham', 'cbcurrencyconverter' ),
			'ALL' => __( 'Albania Lek', 'cbcurrencyconverter' ),
			'AFN' => __( 'Afghanistan Afghani', 'cbcurrencyconverter' ),
			'ARS' => __( 'Argentina Peso', 'cbcurrencyconverter' ),
			'AWG' => __( 'Aruba Guilder', 'cbcurrencyconverter' ),
			'AUD' => __( 'Australia Dollar', 'cbcurrencyconverter' ),
			'AZN' => __( 'Azerbaijan New Manat', 'cbcurrencyconverter' ),
			'BSD' => __( 'Bahamas Dollar', 'cbcurrencyconverter' ),
			'BBD' => __( 'Barbados Dollar', 'cbcurrencyconverter' ),
			'BDT' => __( 'Bangladeshi Taka', 'cbcurrencyconverter' ),
			'BYR' => __( 'Belarus Ruble', 'cbcurrencyconverter' ),
			'BZD' => __( 'Belize Dollar', 'cbcurrencyconverter' ),
			'BMD' => __( 'Bermuda Dollar', 'cbcurrencyconverter' ),
			'BOB' => __( 'Bolivia Boliviano', 'cbcurrencyconverter' ),
			'BAM' => __( 'Bosnia and Herzegovina Convertible Marka', 'cbcurrencyconverter' ),
			'BWP' => __( 'Botswana Pula', 'cbcurrencyconverter' ),
			'BGN' => __( 'Bulgaria Lev', 'cbcurrencyconverter' ),
			'BRL' => __( 'Brazil Real', 'cbcurrencyconverter' ),
			'BHD' => __( 'Bahrain Dinar', 'cbcurrencyconverter' ),
			'BND' => __( 'Brunei Darussalam Dollar', 'cbcurrencyconverter' ),
			'KHR' => __( 'Cambodia Riel', 'cbcurrencyconverter' ),
			'CAD' => __( 'Canada Dollar', 'cbcurrencyconverter' ),
			'KYD' => __( 'Cayman Islands Dollar', 'cbcurrencyconverter' ),
			'CLP' => __( 'Chile Peso', 'cbcurrencyconverter' ),
			'CNY' => __( 'China Yuan Renminbi', 'cbcurrencyconverter' ),
			'COP' => __( 'Colombia Peso', 'cbcurrencyconverter' ),
			'CRC' => __( 'Costa Rica Colon', 'cbcurrencyconverter' ),
			'HRK' => __( 'Croatia Kuna', 'cbcurrencyconverter' ),
			'CUP' => __( 'Cuba Peso', 'cbcurrencyconverter' ),
			'CZK' => __( 'Czech Republic Koruna', 'cbcurrencyconverter' ),
			'DKK' => __( 'Denmark Krone', 'cbcurrencyconverter' ),
			'DOP' => __( 'Dominican Republic Peso', 'cbcurrencyconverter' ),
			'XCD' => __( 'East Caribbean Dollar', 'cbcurrencyconverter' ),
			'EGP' => __( 'Egypt Pound', 'cbcurrencyconverter' ),
			'SVC' => __( 'El Salvador Colon', 'cbcurrencyconverter' ),
			'EEK' => __( 'Estonia Kroon', 'cbcurrencyconverter' ),
			'EUR' => __( 'Euro Member Countries', 'cbcurrencyconverter' ),
			'FKP' => __( 'Falkland Islands (Malvinas) Pound', 'cbcurrencyconverter' ),
			'FJD' => __( 'Fiji Dollar', 'cbcurrencyconverter' ),
			'GEL' => __( 'Georgian Lari', 'cbcurrencyconverter' ),
			'GHC' => __( 'Ghana Cedis', 'cbcurrencyconverter' ),
			'GIP' => __( 'Gibraltar Pound', 'cbcurrencyconverter' ),
			'GTQ' => __( 'Guatemala Quetzal', 'cbcurrencyconverter' ),
			'GGP' => __( 'Guernsey Pound', 'cbcurrencyconverter' ),
			'GYD' => __( 'Guyana Dollar', 'cbcurrencyconverter' ),
			'HNL' => __( 'Honduras Lempira', 'cbcurrencyconverter' ),
			'HKD' => __( 'Hong Kong Dollar', 'cbcurrencyconverter' ),
			'HUF' => __( 'Hungary Forint', 'cbcurrencyconverter' ),
			'ISK' => __( 'Iceland Krona', 'cbcurrencyconverter' ),
			'INR' => __( 'India Rupee', 'cbcurrencyconverter' ),
			'IDR' => __( 'Indonesia Rupiah', 'cbcurrencyconverter' ),
			'IRR' => __( 'Iran Rial', 'cbcurrencyconverter' ),
			'IMP' => __( 'Isle of Man Pound', 'cbcurrencyconverter' ),
			'ILS' => __( 'Israel Shekel', 'cbcurrencyconverter' ),
			'JMD' => __( 'Jamaica Dollar', 'cbcurrencyconverter' ),
			'JPY' => __( 'Japan Yen', 'cbcurrencyconverter' ),
			'JEP' => __( 'Jersey Pound', 'cbcurrencyconverter' ),
			'KZT' => __( 'Kazakhstan Tenge', 'cbcurrencyconverter' ),
			'KPW' => __( 'Korea (North) Won', 'cbcurrencyconverter' ),
			'KRW' => __( 'Korea (South) Won', 'cbcurrencyconverter' ),
			'KGS' => __( 'Kyrgyzstan Som', 'cbcurrencyconverter' ),
			'KES' => __( 'Kenya Shilling', 'cbcurrencyconverter' ),
			'LAK' => __( 'Laos Kip', 'cbcurrencyconverter' ),
			'LVL' => __( 'Latvia Lat', 'cbcurrencyconverter' ),
			'LBP' => __( 'Lebanon Pound', 'cbcurrencyconverter' ),
			'LRD' => __( 'Liberia Dollar', 'cbcurrencyconverter' ),
			'LTL' => __( 'Lithuania Litas', 'cbcurrencyconverter' ),
			'MKD' => __( 'Macedonia Denar', 'cbcurrencyconverter' ),
			'MYR' => __( 'Malaysia Ringgit', 'cbcurrencyconverter' ),
			'MUR' => __( 'Mauritius Rupee', 'cbcurrencyconverter' ),
			'MXN' => __( 'Mexico Peso', 'cbcurrencyconverter' ),
			'MNT' => __( 'Mongolia Tughrik', 'cbcurrencyconverter' ),
			'MZN' => __( 'Mozambique Metical', 'cbcurrencyconverter' ),
			'NAD' => __( 'Namibia Dollar', 'cbcurrencyconverter' ),
			'NPR' => __( 'Nepal Rupee', 'cbcurrencyconverter' ),
			'ANG' => __( 'Netherlands Antilles Guilder', 'cbcurrencyconverter' ),
			'NZD' => __( 'New Zealand Dollar', 'cbcurrencyconverter' ),
			'NIO' => __( 'Nicaragua Cordoba', 'cbcurrencyconverter' ),
			'NGN' => __( 'Nigeria Naira', 'cbcurrencyconverter' ),
			'NOK' => __( 'Norway Krone', 'cbcurrencyconverter' ),
			'OMR' => __( 'Oman Rial', 'cbcurrencyconverter' ),
			'PKR' => __( 'Pakistan Rupee', 'cbcurrencyconverter' ),
			'PAB' => __( 'Panama Balboa', 'cbcurrencyconverter' ),
			'PYG' => __( 'Paraguay Guarani', 'cbcurrencyconverter' ),
			'PEN' => __( 'Peru Nuevo Sol', 'cbcurrencyconverter' ),
			'PGK' => __( 'Papua New Guinean Kina', 'cbcurrencyconverter' ),
			'PHP' => __( 'Philippines Peso', 'cbcurrencyconverter' ),
			'PLN' => __( 'Poland Zloty', 'cbcurrencyconverter' ),
			'QAR' => __( 'Qatar Riyal', 'cbcurrencyconverter' ),
			'RON' => __( 'Romania New Leu', 'cbcurrencyconverter' ),
			'RUB' => __( 'Russia Ruble', 'cbcurrencyconverter' ),
			'SHP' => __( 'Saint Helena Pound', 'cbcurrencyconverter' ),
			'SAR' => __( 'Saudi Arabia Riyal', 'cbcurrencyconverter' ),
			'RSD' => __( 'Serbia Dinar', 'cbcurrencyconverter' ),
			'SCR' => __( 'Seychelles Rupee', 'cbcurrencyconverter' ),
			'SGD' => __( 'Singapore Dollar', 'cbcurrencyconverter' ),
			'SBD' => __( 'Solomon Islands Dollar', 'cbcurrencyconverter' ),
			'SOS' => __( 'Somalia Shilling', 'cbcurrencyconverter' ),
			'ZAR' => __( 'South Africa Rand', 'cbcurrencyconverter' ),
			'LKR' => __( 'Sri Lanka Rupee', 'cbcurrencyconverter' ),
			'SEK' => __( 'Sweden Krona', 'cbcurrencyconverter' ),
			'CHF' => __( 'Switzerland Franc', 'cbcurrencyconverter' ),
			'SRD' => __( 'Suriname Dollar', 'cbcurrencyconverter' ),
			'SYP' => __( 'Syria Pound', 'cbcurrencyconverter' ),
			'TWD' => __( 'Taiwan New Dollar', 'cbcurrencyconverter' ),
			'THB' => __( 'Thailand Baht', 'cbcurrencyconverter' ),
			'TTD' => __( 'Trinidad and Tobago Dollar', 'cbcurrencyconverter' ),
			'TRY' => __( 'Turkey Lira', 'cbcurrencyconverter' ),
			'TRL' => __( 'Turkey Lira', 'cbcurrencyconverter' ),
			'TVD' => __( 'Tuvalu Dollar', 'cbcurrencyconverter' ),
			'UAH' => __( 'Ukraine Hryvna', 'cbcurrencyconverter' ),
			'GBP' => __( 'United Kingdom Pound', 'cbcurrencyconverter' ),
			'USD' => __( 'United States Dollar', 'cbcurrencyconverter' ),
			'UYU' => __( 'Uruguay Peso', 'cbcurrencyconverter' ),
			'UGX' => __( 'Ugandan Shilling', 'cbcurrencyconverter' ),
			'UZS' => __( 'Uzbekistan Som', 'cbcurrencyconverter' ),
			'VEF' => __( 'Venezuela Bolivar', 'cbcurrencyconverter' ),
			'VND' => __( 'Viet Nam Dong', 'cbcurrencyconverter' ),
			'YER' => __( 'Yemen Rial', 'cbcurrencyconverter' ),
			'ZWD' => __( 'Zimbabwe Dollar', 'cbcurrencyconverter' ),
			'XOF' => __( 'West African CFA franc', 'cbcurrencyconverter' ),
			'XAF' => __( 'Central African CFA franc', 'cbcurrencyconverter' ),

		);

		$currency_list = apply_filters( 'cbcurrencyconverter_currency_list', $currency_list);

		return $currency_list;
	}//end getCurrencyList

	/**
	 * Get available style reverser
	 *
	 * @return mixed|void
	 */
	public static function getCurrencyList_r() {
		$CurrencyList   = CBCurrencyConverterHelper::getCurrencyList();
		$CurrencyList_r = array();

		foreach ( $CurrencyList as $key => $value ) {
			$CurrencyList_r[ $value ] = $key;
		}

		return apply_filters( 'cbcurrencyconverter_currency_list_r', $CurrencyList_r );
	}//end getCurrencyList_r

	/**
	 * List all global option name with prefix cbxwpbookmark_
	 */
	public static function getAllOptionNames() {
		global $wpdb;

		$prefix       = 'cbcurrencyconverter_';
		$option_names = $wpdb->get_results( "SELECT * FROM {$wpdb->options} WHERE option_name LIKE '{$prefix}%'", ARRAY_A );

		return apply_filters( 'cbcurrencyconverter_option_names', $option_names );
	}//end getAllOptionNames

	/**
	 * Shortcode builder for display and copy paste purpose
	 *
	 * @param array $global_settings
	 * @param array $calculator_setting
	 * @param array $list_settings
	 *
	 * @return string
	 * @throws Exception
	 */
	public static function shortcode_builder( $global_settings = array(), $calculator_setting = array(), $list_settings = array() ) {

		//$global_settings     = get_option( 'cbcurrencyconverter_global_settings' );
		//$list_settings       = get_option( 'cbcurrencyconverter_list_settings' );
		//$calculator_settings = get_option( 'cbcurrencyconverter_calculator_settings' );


		//general setting
		$layout       = ( isset( $global_settings['cbcurrencyconverter_defaultlayout'] ) ) ? $global_settings['cbcurrencyconverter_defaultlayout'] : 'cal';
		$decimalpoint = ( isset( $global_settings['cbcurrencyconverter_decimalpoint'] ) ) ? $global_settings['cbcurrencyconverter_decimalpoint'] : 2;


		//list setting
		$list_title          = ( isset( $list_settings['cbcurrencyconverter_title_list'] ) ) ? $list_settings['cbcurrencyconverter_title_list'] : esc_html__( 'List of Currency', 'cbcurrencyconverter' ); //list title
		$list_from_currency  = ( isset( $list_settings['cbcurrencyconverter_defaultcurrency_list'] ) ) ? $list_settings['cbcurrencyconverter_defaultcurrency_list'] : 'USD'; //we need to set something as default currency to make the list work
		$list_to_currency    = ( isset( $list_settings['cbcurrencyconverter_tocurrency_list'] ) ) ? $list_settings['cbcurrencyconverter_tocurrency_list'] : array(
			'GBP',
			'CAD',
			'AUD',
		); //list of currency
		$list_default_amount = ( isset( $list_settings['cbcurrencyconverter_defaultamount_forlist'] ) ) ? $list_settings['cbcurrencyconverter_defaultamount_forlist'] : 1; //default amount


		//calculator setting
		$calc_title          = ( isset( $calculator_settings['cbcurrencyconverter_title_cal'] ) ) ? $calculator_settings['cbcurrencyconverter_title_cal'] : esc_html__( 'Currency Calculator', 'cbcurrencyconverter' );
		$calc_from_currency  = ( isset( $calculator_settings['cbcurrencyconverter_fromcurrency'] ) ) ? $calculator_settings['cbcurrencyconverter_fromcurrency'] : 'USD';
		$calc_to_currency    = ( isset( $calculator_settings['cbcurrencyconverter_tocurrency'] ) ) ? $calculator_settings['cbcurrencyconverter_tocurrency'] : 'CAD';
		$calc_default_amount = ( isset( $calculator_settings['cbcurrencyconverter_defaultamount_for_calculator'] ) ) ? $calculator_settings['cbcurrencyconverter_defaultamount_for_calculator'] : 1;

		$calc_currencies = ( isset( $calculator_settings['cbcurrencyconverter_enabledcurrencies_calculator'] ) ) ? $calculator_settings['cbcurrencyconverter_enabledcurrencies_calculator'] : array(
			'USD',
			'GBP',
			'CAD',
			'AUD',
		);


		$attr = array(
			'layout'              => $layout,//cal, list, calwithlisttop, calwithlistbottom
			'decimalpoint'        => $decimalpoint, //this is common for cal and list both
			'calc_currencies'     => implode( ',', $calc_currencies ),//list of currency, comma separated user input, example USD,GBP
			'calc_title'          => $calc_title,//string
			'calc_from_currency'  => $calc_from_currency,
			'calc_to_currency'    => $calc_to_currency,
			'calc_default_amount' => $calc_default_amount,//numeric value
			'list_title'          => $list_title,// string
			'list_from_currency'  => $list_from_currency,
			'list_to_currency'    => implode( ',', $list_to_currency ),//comma separated, example  GBP,BDT
			'list_default_amount' => $list_default_amount,//numeric value

		);


		//$attr['calc_currencies']  = explode( ',', $attr['calc_currencies'] );
		//$attr['list_to_currency'] = explode( ',', $attr['list_to_currency'] );


		$attr = apply_filters( 'cbcurrencyconverter_shortcode_builder_attr', $attr );

		$attr_html = '';

		foreach ( $attr as $key => $value ) {
			$attr_html .= ' ' . $key . '="' . $value . '" ';
		}

		return '[cbcurrencyconverter ' . $attr_html . ']';
	}//end shortcode_builder

	/**
	 * Add utm params to any url
	 *
	 * @param string $url
	 *
	 * @return string
	 */
	public static function url_utmy( $url = '' ) {
		if ( $url == '' ) {
			return $url;
		}

		$url = add_query_arg( array(
			'utm_source'   => 'plgsidebarinfo',
			'utm_medium'   => 'plgsidebar',
			'utm_campaign' => 'wpfreemium',
		), $url );

		return $url;
	}//end url_utmy
}//end of class CBCurrencyConverterHelper


if ( ! function_exists( 'cbxcccalcview' ) ):
	/**
	 * Shows the calculator form
	 *
	 * @param string $cbcur_reference shortcode or widget
	 * @param array $instance
	 *
	 * @return string
	 *
	 */
	function cbxcccalcview( $cbcur_reference, $instance = array() ) {
		cbcurrencyconverter_deprecated_function( 'cbxcccalcview function', '2.2', 'CBCurrencyConverterHelper::cbxcccalcview' );

		return CBCurrencyConverterHelper::cbxcccalcview( $cbcur_reference, $instance );
	}//end function cbxcccalcview
endif;


if ( ! function_exists( 'cbxcclistview' ) ):
	/**
	 * currencly list layout
	 *
	 * @param string $cbcur_reference shortcode or widget
	 * @param array $instance
	 *
	 * @return string
	 */
	function cbxcclistview( $cbcur_reference, $instance = array() ) {
		cbcurrencyconverter_deprecated_function( 'cbxcclistview function', '2.2', 'CBCurrencyConverterHelper::cbxcclistview' );

		return CBCurrencyConverterHelper::cbxcclistview( $cbcur_reference, $instance );
	}//end function cbxcclistview
endif;

/**
 * Shows the calculator in woocommerce
 *
 * @param       $cbcur_reference
 * @param array $instance
 *
 * @return string
 */
if ( ! function_exists( 'cbxcccalcinline' ) ):
	function cbxcccalcinline( $cbcur_reference, $instance = array() ) {
		cbcurrencyconverter_deprecated_function( 'cbxcccalcinline function', '2.2', 'CBCurrencyConverterHelper::cbxcccalcinline' );

		return CBCurrencyConverterHelper::cbxcccalcinline( $cbcur_reference, $instance );
	}//end function cbxcccalcinline
endif;