<?php

class CBCurrencyConverterAlphavantage{
    /**
     * alphavantage.co api method
     *
     * @since 2.8.0
     *
     * @param     $convertion_value
     * @param     $price
     * @param     $convert_from
     * @param     $convert_to
     * @param int $decimalpoint
     *
     * @return string
     */
    public static function api_method( $convertion_value = 0, $price, $convert_from, $convert_to, $decimalpoint = 2 ) {

        $setting = new CBCurrencyconverterSetting();

        $cache         = intval( $setting->get_option( 'cbcurrencyconverter_ratecache', 'cbcurrencyconverter_global_settings', 1 ) ); //from version 2.7.1
        $cache_time_hr = intval( $setting->get_option( 'cbcurrencyconverter_cachetime', 'cbcurrencyconverter_global_settings', 2 ) ); //from version 2.7.1

        if ( $cache ) {
            // Get any existing copy of our transient data
            if ( false === ( $convertion_cache = get_transient( 'cbcurrencyconverter_alphavantage' ) ) ) {
                $convertion_cache                                    = array();
                $convertion_value                                    = CBCurrencyConverterAlphavantage::api_get( $convert_from, $convert_to );
                $convertion_cache[ $convert_from . '-' . $convert_to ] = $convertion_value;
                $convertion_cache                                    = maybe_serialize( $convertion_cache );

                //https://codex.wordpress.org/Transients_API
                set_transient( 'cbcurrencyconverter_alphavantage', $convertion_cache, $cache_time_hr * HOUR_IN_SECONDS );

                $convertion_value = $convertion_value * $price;
                $convertion_value = apply_filters( 'cbcurrencyconverter_rate_final', $convertion_value, $price, $convert_from, $convert_to, $decimalpoint );

                return number_format_i18n( $convertion_value, $decimalpoint );
            }

            $convertion_cache = maybe_unserialize( $convertion_cache );
            if ( isset( $convertion_cache[ $convert_from . '-' . $convert_to ] ) ) {
                $convertion_value = $convertion_cache[ $convert_from . '-' . $convert_to ];
            } else {
                $convertion_value                                    = CBCurrencyConverterAlphavantage::api_get( $convert_from, $convert_to );
                $convertion_cache[ $convert_from . '-' . $convert_to ] = $convertion_value;
                $convertion_cache                                    = maybe_serialize( $convertion_cache );

                //https://codex.wordpress.org/Transients_API
                set_transient( 'cbcurrencyconverter_alphavantage', $convertion_cache, $cache_time_hr * HOUR_IN_SECONDS );
            }
        } else {
            $convertion_value = CBCurrencyConverterAlphavantage::api_get( $convert_from, $convert_to );
        }


        //return number_format_i18n( ( $convertion_value * $price ), $decimalpoint );
        //return number_format_i18n( ( $convertion_value * $price ), $decimalpoint );

        $convertion_value = $convertion_value * $price;
        $convertion_value = apply_filters( 'cbcurrencyconverter_rate_final', $convertion_value, $price, $convert_from, $convert_to, $decimalpoint );

        return number_format_i18n( $convertion_value, $decimalpoint );
    }//end api_method

    /**
     * api request to alphavantage.co
     *
     * @since 2.8.0
     *
     * @param $convert_from
     * @param $convert_to
     *
     * @return int
     */
    public static function api_get( $convert_from, $convert_to ) {

        $setting = new CBCurrencyconverterSetting();
        $api_key = $setting->get_option( 'apikey', 'cbcurrencyconverter_global_settings', '' );

        if ( $api_key == '' ) {
            return 0;
        }


        $url = 'https://www.alphavantage.co/query?function=CURRENCY_EXCHANGE_RATE&from_currency=' . urlencode( $convert_from ) . '&to_currency=' . urlencode( $convert_to ) . '&apikey=' . $api_key;
        $ch  = curl_init();

        curl_setopt( $ch, CURLOPT_URL, $url );
        curl_setopt( $ch, CURLOPT_RETURNTRANSFER, 1 );
        curl_setopt( $ch, CURLOPT_HEADER, 0 );
        curl_setopt( $ch, CURLOPT_SSL_VERIFYPEER, false );
        $body = curl_exec( $ch );

        curl_close( $ch );

        $result = json_decode( $body, true );
        $result = array_values( $result );

        if ( is_array( $result[0] ) ) {
            $result        = array_values( $result[0] );
            $from_currency = $result[0];
            $to_currency   = $result[1];
            $value         = $result[4];

            return $value;
        }

        return 0;
    }//end api_get
}
