<?php

	// If this file is called directly, abort.
	if ( ! defined( 'WPINC' ) ) {
		die;
	}

	/**
	 * Class CbCurrencyConverterwidget
	 */
	class CBCurrencyConverterWidget extends WP_Widget {

		/**
		 *
		 *
		 * Unique identifier for  widget.
		 *
		 *
		 * The variable name is used as the text domain when internationalizing strings
		 * of text. Its value should match the Text Domain file header in the main
		 * widget file.
		 *
		 * @since    1.0.0
		 *
		 * @var      string
		 */
		protected $widget_slug = 'cbcurrencyconverterwidget';

		/*--------------------------------------------------*/
		/* Constructor
		/*--------------------------------------------------*/

		/**
		 * Specifies the classname and description, instantiates the widget,
		 * loads localization files, and includes necessary stylesheets and JavaScript.
		 */
		public function __construct() {
			parent::__construct(
				$this->widget_slug,
				esc_html__( 'CBX Currency Converter', 'cbcurrencyconverter' ),
				array(
					'classname'   => $this->widget_slug . '-class',
					'description' => esc_html__( 'Currency Converter', 'cbcurrencyconverter' ),
				)
			);


		} // end constructor


		/**
		 * Outputs the content of the widget.
		 *
		 * @param array args  The array of form elements
		 * @param array instance The current instance of the widget
		 */
		public function widget( $args, $instance ) {
			extract( $args, EXTR_SKIP );


			$setting_global = get_option( 'cbcurrencyconverter_global_settings' );
			$setting_list   = get_option( 'cbcurrencyconverter_list_settings' );
			$setting_cal    = get_option( 'cbcurrencyconverter_calculator_settings' );

			//get default values from global settings

			//general setting
			$layout       = ( isset( $setting_global['cbcurrencyconverter_defaultlayout'] ) ) ? $setting_global['cbcurrencyconverter_defaultlayout'] : 'cal';
			$decimalpoint = ( isset( $setting_global['cbcurrencyconverter_decimalpoint'] ) ) ? intval( $setting_global['cbcurrencyconverter_decimalpoint'] ) : 2;

			//calculator setting
			$calc_currencies     = ( isset( $setting_cal['cbcurrencyconverter_enabledcurrencies_calculator'] ) ) ? $setting_cal['cbcurrencyconverter_enabledcurrencies_calculator'] : array( 'USD', 'GBP', 'CAD', 'AUD' );
			$cbcur_from_currency = ( isset( $setting_cal['cbcurrencyconverter_fromcurrency'] ) ) ? $setting_cal['cbcurrencyconverter_fromcurrency'] : 'USD';
			$cbcur_to_currency   = ( isset( $setting_cal['cbcurrencyconverter_tocurrency'] ) ) ? $setting_cal['cbcurrencyconverter_tocurrency'] : 'CAD';
			$calc_default_amount = ( isset( $setting_cal['cbcurrencyconverter_defaultamount_for_calculator'] ) ) ? floatval( $setting_cal['cbcurrencyconverter_defaultamount_for_calculator'] ) : 1;
			$calc_title          = ( isset( $setting_cal['cbcurrencyconverter_title_cal'] ) ) ? $setting_cal['cbcurrencyconverter_title_cal'] : esc_html__( 'Currency Calculator', 'cbcurrencyconverter' );

			//list setting
			$list_from_currency  = ( isset( $setting_list['cbcurrencyconverter_defaultcurrency_list'] ) ) ? $setting_list['cbcurrencyconverter_defaultcurrency_list'] : 'USD'; //we need to set something as default currency to make the list work
			$list_to_currency    = ( isset( $setting_list['cbcurrencyconverter_tocurrency_list'] ) ) ? $setting_list['cbcurrencyconverter_tocurrency_list'] : array( 'GBP', 'CAD', 'AUD' ); //list of currency
			$list_default_amount = ( isset( $setting_list['cbcurrencyconverter_defaultamount_forlist'] ) ) ? floatval( $setting_list['cbcurrencyconverter_defaultamount_forlist'] ) : 1; //default amount
			$list_title          = ( isset( $setting_list['cbcurrencyconverter_title_list'] ) ) ? $setting_list['cbcurrencyconverter_title_list'] : esc_html__( 'List of Currency', 'cbcurrencyconverter' ); //list title


			//$instance = apply_filters( 'cbcurrencyconverter_widget_output', $instance );

			$instance['layout']       = isset( $instance['layout'] ) ? sanitize_text_field( $instance['layout'] ) : $layout;
			$instance['decimalpoint'] = isset( $instance['decimalpoint'] ) ? intval( $instance['decimalpoint'] ) : $decimalpoint;

			$instance['calc_title ']         = isset( $instance['calc_title '] ) ? sanitize_text_field( $instance['calc_title '] ) : $calc_title;
			$instance['cbcur_from_currency'] = isset( $instance['cbcur_from_currency'] ) ? sanitize_text_field( $instance['cbcur_from_currency'] ) : $cbcur_from_currency;
			$instance['cbcur_to_currency']   = isset( $instance['cbcur_to_currency'] ) ? sanitize_text_field( $instance['cbcur_to_currency'] ) : $cbcur_to_currency;
			$instance['calc_default_amount'] = isset( $instance['calc_default_amount'] ) ? floatval( $instance['calc_default_amount'] ) : $calc_default_amount;
			$instance['calc_currencies']     = isset( $instance['calc_currencies'] ) ? wp_unslash( $instance['calc_currencies'] ) : $calc_currencies;

			$instance['list_title ']         = isset( $instance['list_title '] ) ? sanitize_text_field( $instance['list_title '] ) : $list_title;
			$instance['list_from_currency']  = isset( $instance['list_from_currency'] ) ? sanitize_text_field( $instance['list_from_currency'] ) : $list_from_currency;
			$instance['list_to_currency']    = isset( $instance['list_to_currency'] ) ? wp_unslash( $instance['list_to_currency'] ) : $list_to_currency;
			$instance['list_default_amount'] = isset( $instance['list_default_amount'] ) ? floatval( $instance['list_default_amount'] ) : $list_default_amount;


			extract( $instance );

			echo $before_widget;

			$title = empty( $instance['title'] ) ? ' ' : apply_filters( 'widget_title', $instance['title'] );
			if ( ! empty( $title ) ) {
				echo $before_title . $title . $after_title;
			};


			if ( $layout == 'list' ) {
				echo CBCurrencyConverterHelper::cbxcclistview( 'widget', $instance );
			} elseif ( $layout == 'cal' ) {
				echo CBCurrencyConverterHelper::cbxcccalcview( 'widget', $instance );
			} elseif ( $layout == 'calwithlistbottom' ) {
				echo CBCurrencyConverterHelper::cbxcccalcview( 'widget', $instance ) . CBCurrencyConverterHelper::cbxcclistview( 'widget', $instance );
			} elseif ( $layout == 'calwithlisttop' ) {
				echo CBCurrencyConverterHelper::cbxcclistview( 'widget', $instance ) . CBCurrencyConverterHelper::cbxcccalcview( 'widget', $instance );
			}

			echo $after_widget;

		}//end widget


		/**
		 * Processes the widget's options to be saved.
		 *
		 * @param array $new_instance
		 * @param array $old_instance
		 *
		 * @return array|bool
		 */
		public function update( $new_instance, $old_instance ) {
			if ( ! isset( $new_instance['submit'] ) ) {
				return false;
			}
			$instance = $old_instance;

			$instance['title'] 			= sanitize_text_field( $new_instance['title'] );
			$instance['layout']       	= sanitize_text_field( $new_instance['layout'] );
			$instance['decimalpoint'] 	= intval( $new_instance['decimalpoint'] );

			//calculator settings
			$instance['calc_title']          = sanitize_text_field( $new_instance['calc_title'] );
			$instance['calc_currencies']     = wp_unslash( $new_instance['calc_currencies'] );
			$instance['calc_from_currency']  = sanitize_text_field( $new_instance['calc_from_currency'] );
			$instance['calc_to_currency']    = sanitize_text_field( $new_instance['calc_to_currency'] );
			$instance['calc_default_amount'] = floatval( $new_instance['calc_default_amount'] );

			//list settings
			$instance['list_title']          = sanitize_text_field( $new_instance['list_title'] );
			$instance['list_from_currency']  = sanitize_text_field( $new_instance['list_from_currency'] );
			$instance['list_to_currency']    = wp_unslash( $new_instance['list_to_currency'] );
			$instance['list_default_amount'] = floatval( $new_instance['list_default_amount'] );

			return $instance;
		}//end widget

		/**
		 * Generates the administration form for the widget.
		 *
		 * @param array instance The array of keys and values for the widget.
		 */
		public function form( $instance ) {

			$setting_global = get_option( 'cbcurrencyconverter_global_settings' );
			$setting_list   = get_option( 'cbcurrencyconverter_list_settings' );
			$setting_cal    = get_option( 'cbcurrencyconverter_calculator_settings' );

			//get default values from global settings

			//general setting
			$layout       = ( isset( $setting_global['cbcurrencyconverter_defaultlayout'] ) ) ? $setting_global['cbcurrencyconverter_defaultlayout'] : 'cal';
			$decimalpoint = ( isset( $setting_global['cbcurrencyconverter_decimalpoint'] ) ) ? $setting_global['cbcurrencyconverter_decimalpoint'] : 2;

			//calculator setting
			$calc_title          = ( isset( $setting_cal['cbcurrencyconverter_title_cal'] ) ) ? $setting_cal['cbcurrencyconverter_title_cal'] : esc_html__( 'Currency Calculator', 'cbcurrencyconverter' );
			$calc_from_currency  = ( isset( $setting_cal['cbcurrencyconverter_fromcurrency'] ) ) ? $setting_cal['cbcurrencyconverter_fromcurrency'] : 'USD';
			$calc_to_currency    = ( isset( $setting_cal['cbcurrencyconverter_tocurrency'] ) ) ? $setting_cal['cbcurrencyconverter_tocurrency'] : 'CAD';
			$calc_default_amount = ( isset( $setting_cal['cbcurrencyconverter_defaultamount_for_calculator'] ) ) ? $setting_cal['cbcurrencyconverter_defaultamount_for_calculator'] : 1;
			$calc_currencies     = ( isset( $setting_cal['cbcurrencyconverter_enabledcurrencies_calculator'] ) ) ? $setting_cal['cbcurrencyconverter_enabledcurrencies_calculator'] : array( 'USD', 'GBP', 'CAD', 'AUD' );

			//list setting
			$list_title          = ( isset( $setting_list['cbcurrencyconverter_title_list'] ) ) ? $setting_list['cbcurrencyconverter_title_list'] : esc_html__( 'List of Currency', 'cbcurrencyconverter' ); //list title
			$list_from_currency  = ( isset( $setting_list['cbcurrencyconverter_defaultcurrency_list'] ) ) ? $setting_list['cbcurrencyconverter_defaultcurrency_list'] : 'USD'; //we need to set something as default currency to make the list work
			$list_to_currency    = ( isset( $setting_list['cbcurrencyconverter_tocurrency_list'] ) ) ? $setting_list['cbcurrencyconverter_tocurrency_list'] : array( 'GBP', 'CAD', 'AUD' ); //list of currency
			$list_default_amount = ( isset( $setting_list['cbcurrencyconverter_defaultamount_forlist'] ) ) ? $setting_list['cbcurrencyconverter_defaultamount_forlist'] : 1; //default amount


			$instance = wp_parse_args( (array) $instance,
				array(
					'title' => esc_html__( 'Currency Calculator', 'cbcurrencyconverter' ),

					'layout'       => $layout,
					'decimalpoint' => $decimalpoint,

					'calc_title'          => $calc_title,
					'calc_from_currency'  => $calc_from_currency,
					'calc_to_currency'    => $calc_to_currency,
					'calc_default_amount' => $calc_default_amount,
					'calc_currencies'     => $calc_currencies,

					'list_title'          => $list_title,
					'list_from_currency'  => $list_from_currency,
					'list_to_currency'    => $list_to_currency,
					'list_default_amount' => $list_default_amount,
				) );

			$title        = sanitize_text_field( $instance['title'] );
			$layout       = sanitize_text_field( $instance['layout'] );
			$decimalpoint = intval( $instance['decimalpoint'] );


			if ( is_array( $instance['calc_currencies'] ) ) {
				$calc_currencies = wp_unslash( $instance['calc_currencies'] );
			} else {
				$calc_currencies = array();
			}


			$calc_title          = sanitize_text_field( $instance['calc_title'] );
			$calc_from_currency  = sanitize_text_field( $instance['calc_from_currency'] );
			$calc_to_currency    = sanitize_text_field( $instance['calc_to_currency'] );
			$calc_default_amount = floatval( $instance['calc_default_amount'] );


			$list_title         = sanitize_text_field( $instance['list_title'] );
			$list_from_currency = sanitize_text_field( $instance['list_from_currency'] );


			if ( is_array( $instance['list_to_currency'] ) ) {
				$list_to_currency = wp_unslash( $instance['list_to_currency'] );
			} else {
				$list_to_currency = array();
			}

			$list_default_amount = floatval( $instance['list_default_amount'] );


			?>
			<div class="cbcurrencyconverter-admin-widget-wrap">
				<p>
					<label for="<?php echo $this->get_field_id( 'title' ); ?>">
						<?php esc_html_e( 'Title', 'cbcurrencyconverter' ); ?>
						<input class="widefat" id="<?php echo $this->get_field_id( 'title' ); ?>" name="<?php echo $this->get_field_name( 'title' ); ?>" type="text" value="<?php echo esc_attr( $title ); ?>" /> </label>
				</p>

				<div class="selecttwo-select-wrapper">
					<label for="<?php echo $this->get_field_id( 'layout' ); ?>"><?php esc_html_e( 'Select Layout:', 'cbcurrencyconverter' ); ?></label>
					<select name="<?php echo $this->get_field_name( 'layout' ); ?>" id="<?php echo $this->get_field_id( 'layout' ); ?>" class="selecttwo-select widefat">
						<option value="cal" <?php selected( $layout, 'cal' ); ?>><?php esc_html_e( 'Calculator', 'cbcurrencyconverter' ); ?></option>
						<option value="list" <?php selected( $layout, 'list' ); ?>><?php esc_html_e( 'List', 'cbcurrencyconverter' ); ?></option>
						<option value="calwithlistbottom" <?php selected( $layout, 'calwithlistbottom' ); ?>><?php esc_html_e( 'Calc with List Bottom', 'cbcurrencyconverter' ); ?></option>
						<option value="calwithlisttop" <?php selected( $layout, 'calwithlisttop' ); ?>><?php esc_html_e( 'Calc with List Top', 'cbcurrencyconverter' ); ?></option>
					</select>
				</div>

				<p>
					<label for="<?php echo $this->get_field_id( 'decimalpoint ' ); ?>">
						<?php esc_html_e( 'Decimal Point', 'cbcurrencyconverter' ); ?>
						<input class="widefat cbcurrencyconverter_decimalpoint" id="<?php echo $this->get_field_id( 'decimalpoint' ); ?>" name="<?php echo $this->get_field_name( 'decimalpoint' ); ?>" type="number" value="<?php echo intval( $decimalpoint ); ?>" /> </label>
				</p>

				<p><h3><?php esc_html_e( 'Calculator settings', 'cbcurrencyconverteraddon' ) ?></h3></p>

				<p>
					<label for="<?php echo $this->get_field_id( 'calc_title' ); ?>">
						<?php esc_html_e( 'Calculator Header:', 'cbcurrencyconverteraddon' ); ?>
						<input class="widefat" id="<?php echo $this->get_field_id( 'calc_title' ); ?>" name="<?php echo $this->get_field_name( 'calc_title' ); ?>" type="text" value="<?php echo $calc_title; ?>" /> </label>
				</p>
				<?php
					$all_currencies = CBCurrencyConverterHelper::getCurrencyList();


				?>

				<div class="selecttwo-select-wrapper">
					<label for="<?php echo $this->get_field_id( 'calc_currencies' ); ?>"><?php esc_html_e( 'Calculator Enabled Currencies', 'cbcurrencyconverteraddon' ); ?></label>
                    <div class="clear clearfix"></div>
					<select name="<?php echo $this->get_field_name( 'calc_currencies' ) . '[]'; ?>" id="<?php echo $this->get_field_id( 'calc_currencies' ); ?>" multiple="multiple" class="widefat selecttwo-select">
						<?php foreach ( $all_currencies as $key => $title ) { ?>
							<option value="<?php echo $key; ?>" <?php echo in_array( $key, $calc_currencies ) ? 'selected ' : ''; ?>>
								<?php echo $title . ' - ' . $key; ?>
							</option>
						<?php } ?>
					</select>
				</div>

				<?php
					$all_currencies = CBCurrencyConverterHelper::getCurrencyList();

					if ( is_array( $calc_currencies ) && sizeof( $calc_currencies ) > 0 ) {

						foreach ( $all_currencies as $key => $value ) {
							if ( ! in_array( $key, $calc_currencies ) ) {
								unset( $all_currencies[ $key ] );
							}
						}
					}

				?>
				<div class="selecttwo-select-wrapper">
					<label for="<?php echo $this->get_field_id( 'calc_from_currency' ); ?>"><?php esc_html_e( 'Calculator From Currency', 'cbcurrencyconverteraddon' ); ?></label>
					<select name="<?php echo $this->get_field_name( 'calc_from_currency' ); ?>"
							id="<?php echo $this->get_field_id( 'calc_from_currency' ); ?>" class="selecttwo-select widefat">
						<?php foreach ( $all_currencies as $index => $all_currenciescalc ) { ?>
							<option value="<?php echo $index; ?>"<?php selected( $index, $calc_from_currency ); ?>><?php echo $all_currenciescalc . ' - ' . $index; ?></option>
						<?php } ?>
					</select>
				</div>

				<div class="selecttwo-select-wrapper">
					<label for="<?php echo $this->get_field_id( 'calc_to_currency' ); ?>"><?php esc_html_e( 'Calculator To Currency', 'cbcurrencyconverteraddon' ); ?></label>
					<select name="<?php echo $this->get_field_name( 'calc_to_currency' ); ?>"
							id="<?php echo $this->get_field_id( 'calc_to_currency' ); ?>" class="selecttwo-select widefat">
						<?php foreach ( $all_currencies as $index => $currency ) { ?>
							<option
								value="<?php echo $index; ?>"<?php selected( $index, $calc_to_currency ); ?>><?php echo $currency . ' - ' . $index; ?></option>
						<?php } ?>
					</select>
				</div>

				<p>
					<label for="<?php echo $this->get_field_id( 'calc_default_amount' ); ?>">
						<?php esc_html_e( 'Default Amount for Calculator', 'cbcurrencyconverteraddon' ); ?>
						<input class="widefat" id="<?php echo $this->get_field_id( 'calc_default_amount' ); ?>"
							   name="<?php echo $this->get_field_name( 'calc_default_amount' ); ?>" type="number" step="any"
							   value="<?php echo floatval( $calc_default_amount ); ?>" /> </label>
				</p>

				<p><h3><?php esc_html_e( 'List settings', 'cbcurrencyconverteraddon' ) ?></h3></p>

				<p>
					<label for="<?php echo $this->get_field_id( 'list_title' ); ?>">
						<?php esc_html_e( 'List Header:', 'cbcurrencyconverteraddon' ); ?>
						<input class="widefat" id="<?php echo $this->get_field_id( 'list_title' ); ?>"
							   name="<?php echo $this->get_field_name( 'list_title' ); ?>" type="text"
							   value="<?php echo $list_title; ?>" /> </label>
				</p>

				<?php
					$all_currencies = CBCurrencyConverterHelper::getCurrencyList();
				?>
				<div class="selecttwo-select-wrapper">
					<label for="<?php echo $this->get_field_id( 'list_from_currency' ); ?>"><?php esc_html_e( 'List From Currency', 'cbcurrencyconverteraddon' ); ?></label>
					<select name="<?php echo $this->get_field_name( 'list_from_currency' ); ?>"
							id="<?php echo $this->get_field_id( 'list_from_currency' ); ?>" class="selecttwo-select widefat">
						<?php foreach ( $all_currencies as $index => $all_currenciescalc ) { ?>
							<option
								value="<?php echo $index; ?>"<?php selected( $index, $list_from_currency ); ?>><?php echo $all_currenciescalc . ' - ' . $index; ?></option>
						<?php } ?>
					</select>
				</div>



				<div class="selecttwo-select-wrapper cbcurrencylist">
					<label for="<?php echo $this->get_field_id( 'list_to_currency' ); ?>"><?php esc_html_e( 'List To Currencies', 'cbcurrencyconverteraddon' ); ?></label>
                    <div class="clear clearfix"></div>
					<select name="<?php echo $this->get_field_name( 'list_to_currency' ) . '[]'; ?>"
							id="<?php echo $this->get_field_id( 'list_to_currency' ); ?>" multiple="multiple" class="widefat selecttwo-select">
						<?php foreach ( $all_currencies as $index => $currency ) { ?>
							<option
								value="<?php echo $index; ?>"<?php echo in_array( $index, $list_to_currency ) ? 'selected ' : ''; ?>><?php echo $currency . ' - ' . $index; ?></option>
						<?php } ?>
					</select>
				</div>

				<p>
					<label for="<?php echo $this->get_field_id( 'list_default_amount ' ); ?>">
						<?php esc_html_e( 'Default Amount for List', 'cbcurrencyconverteraddon' ); ?>
						<input class="widefat" id="<?php echo $this->get_field_id( 'list_default_amount' ); ?>"
							   name="<?php echo $this->get_field_name( 'list_default_amount' ); ?>" type="number" step="any"
							   value="<?php echo floatval( $list_default_amount ); ?>" /> </label>
				</p>
				<input type="hidden" id="<?php echo $this->get_field_id( 'submit' ); ?>"
					   name="<?php echo $this->get_field_name( 'submit' ); ?>" value="1" />
			</div>
            <style type="text/css">
                .selecttwo-select-wrapper .select2-container{
                    width: 100% !important;

                }
            </style>

			<?php

		}//end form
	}//end class CBCurrencyConverterWidget